package com.gosingapore.api;

import com.gosingapore.api.factory.RemoteCustomerFallbackFactory;
import com.cloud.gs.hiring.base.constants.ServiceNameConstants;
import com.cloud.gs.hiring.common.model.dto.CustomerEsDTO;
import com.cloud.gs.hiring.common.model.dto.JobDTO;
import com.cloud.gs.hiring.common.model.vo.CustomerIndustryVO;
import com.cloud.gs.hiring.common.model.vo.FilterCustomerVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @author lsl
 * @date 2021-04-09 18:57
 */
@FeignClient(contextId = "remoteCustomerService", value = ServiceNameConstants.ADVISER_SERVICE, fallbackFactory = RemoteCustomerFallbackFactory.class)
public interface RemoteCustomerService {

    /**
     * 查询客户期望职位
     * @param archiveId
     * @return
     */
    @GetMapping("/customer/getCustomerIndustry/{archiveId}")
    CustomerIndustryVO getCustomerIndustry(@PathVariable("archiveId") Integer archiveId);


    /**
     * 查询职位信息 保存到es中
     * @param jobIdList
     * @return
     */
    @GetMapping("/job/getEsJobList")
    List<JobDTO> getEsJobList(@RequestParam("jobIdList") List<Integer> jobIdList);

    /**
     * 查询客户信息 保存到es中
     * @param archiveIdList archiveIdList
     * @return java.util.List<com.cloud.gs.hiring.common.model.dto.CustomerEsDTO>
     */
    @GetMapping("/customer/getEsCustomerList")
    List<CustomerEsDTO> getEsCustomerList(@RequestParam("archiveIdList") List<Integer> archiveIdList);

    /**
     * 查询过滤用户列表
     * @param jobId jobId
     * @return java.util.List<java.lang.Integer>
     */
    @GetMapping("/customer/getFilterCustomerList")
    FilterCustomerVO getFilterCustomerList(@RequestParam("jobId") Integer jobId);
}
