package com.gosingapore.api;

import com.gosingapore.api.factory.RemoteResourceFallbackFactory;
import com.cloud.gs.hiring.base.constants.ServiceNameConstants;
import com.cloud.gs.hiring.common.model.domain.ErpSysDict;
import com.cloud.gs.hiring.common.model.dto.ErpHometownDTO;
import com.cloud.gs.hiring.common.model.dto.ErpIndustryDTO;
import com.cloud.gs.hiring.common.model.dto.ErpRegionDTO;
import com.cloud.gs.hiring.common.model.dto.ErpSubwayDTO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;

import java.util.List;
import java.util.Map;

/**
 * @author copying
 * @version 3.0
 * @date 2021/3/18 8:28
 */
@FeignClient(contextId = "remoteResourceService",value = ServiceNameConstants.OPERATE_SERVICE,fallbackFactory = RemoteResourceFallbackFactory.class)
public interface RemoteResourceService {

    /**
     * 获取字典列表
     * @param codeType 指定字典的类型
     * @return 字典列表
     */
    @GetMapping("/cache/data/getDict")
    Map<Integer, List<ErpSysDict>> selectSysDict(Integer codeType);

    /**
     * 获取地铁列表
     * @return 地铁列表
     */
    @GetMapping("/cache/data/getSubway")
    List<ErpSubwayDTO> selectSubway();

    /**
     * 获取 中国籍贯
     * @return 中国籍贯
     */
    @GetMapping("/cache/data/getRegion")
    List<ErpRegionDTO> selectRegion();

    /**
     * 获取 马来家乡
     * @return 马来家乡
     */
    @GetMapping("/cache/data/getHometown")
    List<ErpHometownDTO> selectHometown();

    /**
     * 获取 职位类别
     * @return 职位类别
     */
    @GetMapping("/cache/data/getIndustry")
    List<ErpIndustryDTO> selectIndustry();
}
