package com.gosingapore.api;


import com.gosingapore.api.factory.RemoteTokenFallbackFactory;
import com.cloud.gs.hiring.base.constants.ServiceNameConstants;
import com.cloud.gs.hiring.base.util.ApiResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 用户服务
 * 
 * @author ziyi
 */
@FeignClient(contextId = "remoteTokenService", value = ServiceNameConstants.AUTH_SERVICE, fallbackFactory = RemoteTokenFallbackFactory.class)
public interface RemoteTokensService
{
    /**
     * 获取token
     *
     * @param username 用户登录账号(手机号mobile)
     * @return 结果
     */
    @GetMapping(value = "/token")
    ApiResult<OAuth2AccessToken> getToken(@RequestParam String username);

    /**
     * 删除token
     *
     * @param token 登陆人token
     * @return 结果
     */
    @GetMapping(value = "/token/{token}")
    ApiResult<?> removeAccessToken(@PathVariable("token") String token);

    /**
     * 根据用户名,删除erp用户的token
     * @param username 用户名手机
     */
    @PostMapping(value = "/token/remove/{username}")
    void removeErpAccessToken(@PathVariable String username);
}
