package com.gosingapore.api;


import com.gosingapore.api.factory.RemoteUserFallbackFactory;
import com.cloud.gs.hiring.base.constants.ServiceNameConstants;
import com.cloud.gs.hiring.base.util.ApiResult;
import com.cloud.gs.hiring.common.model.domain.ErpSysUser;
import com.cloud.gs.hiring.common.model.domain.ErpUserStorageCapacity;
import com.cloud.gs.hiring.common.model.dto.ErpLoginUser;
import com.cloud.gs.hiring.common.model.dto.ErpSysDepartmentTree;
import com.cloud.gs.hiring.common.model.dto.PageDto;
import com.cloud.gs.hiring.common.model.dto.UserBaseInfoDTO;
import com.cloud.gs.hiring.common.model.query.team.TeamUserQuery;
import com.cloud.gs.hiring.common.model.vo.LibUserInfoVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户服务
 * 
 * @author ziyi
 */
@FeignClient(contextId = "remoteUserService", value = ServiceNameConstants.OPERATE_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService
{
    /**
     * 通过手机号查询用户信息
     *
     * @param mobile 手机号
     * @return 结果
     */
    @GetMapping(value = "/user/info/{mobile}")
    ErpLoginUser selectUserByMobile(@PathVariable( value = "mobile") String mobile);

    /**
     * 根据用户id与角色id获取库容
     *
     * @param userId 用户id
     * @return 结果
     */
    @GetMapping(value = "/user/getStorageCapacityByUserId")
    ErpUserStorageCapacity getStorageCapacityByUserId(@RequestParam("userId") Integer userId);

    /**
     * 查询用户实体信息
     * @param userId 用户id
     * @return 用户信息
     */
    @GetMapping(value = "/user/entityInfo/{userId}")
    ErpSysUser selectUserInfo(@PathVariable(value = "userId") Integer userId);

    /**
     * 获取当前登录人部门下的所有用户
     * @param departmentId 部门id
     * @return 用户列表
     */
    @GetMapping(value = "/user/getDepartmentUsers/{departmentId}")
    List<ErpSysUser> getDepartmentUsers(@PathVariable(value = "departmentId") Integer departmentId);

    /**
     * 获取部门下的子部门列表 (可附带 组员)
     * @param departmentId 部门id
     * @param getUserFlag true 获取用户信息,false 不获取用户信息
     * @return 部门列表
     */
    @GetMapping("/user/getDepartmentList/{departmentId}/{getUserFlag}")
    List<ErpSysDepartmentTree> getDepartmentList(@PathVariable(value = "departmentId") Integer departmentId,@PathVariable(value = "getUserFlag")Boolean getUserFlag);

    /**
     * 修改用户密码
     * @param dto 用户id,用户账号,用户密码
     * @return 结果
     */
    @PostMapping("/user/editPassword")
    ApiResult<?> editPassword(@RequestBody UserBaseInfoDTO dto);

    /**
     * selectLibUserInfoList 组员库获取 组员信息
     * @param query query
     * @return com.cloud.gs.hiring.base.util.ApiResult<com.cloud.gs.hiring.common.model.dto.PageDto<com.cloud.gs.hiring.common.model.dto.LibUserInfo>>
     */
    @PostMapping("/user/teamUserInfoList")
    PageDto<LibUserInfoVO> selectTeamUserInfoList(@RequestBody TeamUserQuery query);

    /**
     * updateStorageCapacity 修改用户库容信息
     * @param capacity capacity
     * @return com.cloud.gs.hiring.base.util.ApiResult<?>
     */
    @PostMapping("/user/updateCapacity")
    ApiResult<?> updateStorageCapacity(@RequestBody ErpUserStorageCapacity capacity);
}
