package com.gosingapore.api.factory;

import com.gosingapore.api.RemoteCustomerService;
import com.cloud.gs.hiring.common.model.dto.CustomerEsDTO;
import com.cloud.gs.hiring.common.model.dto.JobDTO;
import com.cloud.gs.hiring.common.model.vo.CustomerIndustryVO;
import com.cloud.gs.hiring.common.model.vo.FilterCustomerVO;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 日志服务降级处理
 * 
 * @author ziyi
 */
@Component
@Slf4j
public class RemoteCustomerFallbackFactory implements FallbackFactory<RemoteCustomerService>
{
    @Override
    public RemoteCustomerService create(Throwable throwable)
    {
        log.error("客户服务调用失败:{}", throwable.getMessage());
        return new RemoteCustomerService()
        {

            /**
             * 查询客户期望职位
             *
             * @param archiveId
             * @return
             */
            @Override
            public CustomerIndustryVO getCustomerIndustry(Integer archiveId) {
                return null;
            }

            /**
             * 查询职位信息 保存到es中
             *
             * @param jobIdList
             * @return
             */
            @Override
            public List<JobDTO> getEsJobList(List<Integer> jobIdList) {
                return null;
            }

            /**
             * 查询客户信息 保存到es中
             *
             * @param archiveIdList archiveIdList
             * @return java.util.List<com.cloud.gs.hiring.common.model.dto.CustomerEsDTO>
             */
            @Override
            public List<CustomerEsDTO> getEsCustomerList(List<Integer> archiveIdList) {
                return null;
            }

            @Override
            public FilterCustomerVO getFilterCustomerList(Integer jobId) {
                return null;
            }

        };

    }
}
