package com.gosingapore.api.factory;

import com.gosingapore.api.RemoteUserService;
import com.cloud.gs.hiring.base.util.ApiResult;
import com.cloud.gs.hiring.common.model.domain.ErpSysUser;
import com.cloud.gs.hiring.common.model.domain.ErpUserStorageCapacity;
import com.cloud.gs.hiring.common.model.dto.ErpLoginUser;
import com.cloud.gs.hiring.common.model.dto.ErpSysDepartmentTree;
import com.cloud.gs.hiring.common.model.dto.PageDto;
import com.cloud.gs.hiring.common.model.dto.UserBaseInfoDTO;
import com.cloud.gs.hiring.common.model.query.team.TeamUserQuery;
import com.cloud.gs.hiring.common.model.vo.LibUserInfoVO;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.validation.Valid;
import java.util.List;

/**
 * 用户服务降级处理
 * 
 * @author lsl
 */
@Component
@Slf4j
public class RemoteUserFallbackFactory implements FallbackFactory<RemoteUserService>
{
    @Override
    public RemoteUserService create(Throwable throwable)
    {
        log.error("服务调用失败:{}", throwable.getMessage());

        return new RemoteUserService(){

            @Override
            public ErpLoginUser selectUserByMobile(String mobile) {
                return null;
            }

            @Override
            public ErpUserStorageCapacity getStorageCapacityByUserId(Integer userId) {
                return null;
            }

            @Override
            public ErpSysUser selectUserInfo(Integer userId) {
                return null;
            }

            @Override
            public List<ErpSysUser> getDepartmentUsers(Integer departmentId) {
                return null;
            }

            @Override
            public List<ErpSysDepartmentTree> getDepartmentList(Integer departmentId, Boolean getUserFlag) {
                return null;
            }

            @Override
            public ApiResult<?> editPassword(@Valid UserBaseInfoDTO dto) {
                return null;
            }

            @Override
            public PageDto<LibUserInfoVO> selectTeamUserInfoList(TeamUserQuery query) {
                return null;
            }

            @Override
            public ApiResult<?> updateStorageCapacity(ErpUserStorageCapacity capacity) {
                return null;
            }
        };

    }
}
