package com.gosingapore.common.aop;

import com.cloud.gs.hiring.base.util.ResponseCode;
import com.gosingapore.common.constants.CommonConstants;
import com.gosingapore.common.exception.CustomizeException;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * 切面
 * @author lsl
 * @date 2021/4/29 14：57
 */
@Aspect
@Component
@Slf4j
public class IdempotentApiAspect {
    @Resource
    private HttpServletRequest request;
    @Resource
    private RedisTemplate<String, String> redisTemplate;

    @Pointcut("@annotation(com.cloud.gs.hiring.common.annotation.ApiIdempotent)")
    private void pointCut(){}

    @Around("pointCut()")
    public Object handlerServiceMethod(ProceedingJoinPoint jp) throws Throwable {
        String token  = request.getHeader(CommonConstants.TOKEN);

        if(StringUtils.isEmpty(token)){
            throw new CustomizeException(ResponseCode.COMMON_MISS_PARAMETER,"缺少token请求头","Missed Idempotent header");
        }
        boolean hasKey = redisTemplate.hasKey(CommonConstants.IDEMPOTENT_API_KEY + token);
        if(!hasKey){
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW_REPEAT);
        }
        boolean flag = redisTemplate.delete(CommonConstants.IDEMPOTENT_API_KEY + token);
        if(!flag){
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW_REPEAT);
        }
        return jp.proceed();
    }
}
