package com.gosingapore.common.config;

import com.gosingapore.common.properties.BasicSecurityProperties;
import org.springframework.core.annotation.Order;
import org.springframework.security.authentication.dao.DaoAuthenticationProvider;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.crypto.factory.PasswordEncoderFactories;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.security.provisioning.InMemoryUserDetailsManager;

import javax.annotation.Resource;

/**
 * @author shuyan
 */
/*@Configuration*/
@Order(1)
public class BasicSecurityConfig extends WebSecurityConfigurerAdapter {
    @Resource
    private BasicSecurityProperties basicSecurityProperties;

    @Override
    protected void configure(HttpSecurity http) throws Exception {
        HttpSecurity.RequestMatcherConfigurer requestMatchers = http.requestMatchers();
        basicSecurityProperties.getPath().forEach(requestMatchers::antMatchers);
        http
                .authorizeRequests()
                .anyRequest().authenticated()
                .and().cors()
                .and().httpBasic();
    }

    private UserDetailsService inMemoryUserDetailsService() {
        PasswordEncoder encoder = PasswordEncoderFactories.createDelegatingPasswordEncoder();

        UserDetails user = User
                .withUsername(basicSecurityProperties.getUsername())
                .password(encoder.encode(basicSecurityProperties.getPassword()))
                .roles("USER")
                .build();
        return new InMemoryUserDetailsManager(user);
    }

    @Override
    protected void configure(AuthenticationManagerBuilder auth) {
        DaoAuthenticationProvider provider = new DaoAuthenticationProvider();
        provider.setUserDetailsService(inMemoryUserDetailsService());
        auth.authenticationProvider(provider);
    }
}

