package com.gosingapore.common.config;

import com.gosingapore.common.properties.BeetlProperties;
import org.apache.commons.lang.StringUtils;
import org.beetl.core.resource.StringTemplateResourceLoader;
import org.beetl.ext.spring.BeetlGroupUtilConfiguration;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.Properties;

/**
 * @author: QiWenXiao
 */
@Configuration
public class BeetlConf {
    @Autowired
    BeetlProperties beetlProperties;

    @Bean
    public BeetlGroupUtilConfiguration beetlConfig() {
        BeetlGroupUtilConfiguration beetlConf = new BeetlGroupUtilConfiguration();
        beetlConf.setConfigProperties(getProperties());
        // 必须调用此方法
        beetlConf.init();
        beetlConf.getGroupTemplate().setResourceLoader(new StringTemplateResourceLoader());
        return beetlConf;
    }

    private Properties getProperties() {
        Properties properties = new Properties();
        String delimiterPlaceholderStart = beetlProperties.getDelimiterPlaceholderStart();
        if (StringUtils.isNotBlank(delimiterPlaceholderStart)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_PLACEHOLDER_START, delimiterPlaceholderStart);
        }
        String delimiterPlaceholderEnd = beetlProperties.getDelimiterPlaceholderEnd();
        if (StringUtils.isNotBlank(delimiterPlaceholderEnd)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_PLACEHOLDER_END, delimiterPlaceholderEnd);
        }
        String delimiterStatementStart = beetlProperties.getDelimiterStatementStart();
        if (StringUtils.isNotBlank(delimiterStatementStart)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_STATEMENT_START, delimiterStatementStart);
        }
        String delimiterStatementEnd = beetlProperties.getDelimiterStatementEnd();
        if (StringUtils.isNotBlank(delimiterStatementEnd)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_STATEMENT_END, delimiterStatementEnd);
        }
        String delimiterPlaceholderStart2 = beetlProperties.getDelimiterPlaceholderStart2();
        if (StringUtils.isNotBlank(delimiterPlaceholderStart2)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_PLACEHOLDER_START2, delimiterPlaceholderStart2);
        }
        String delimiterPlaceholderEnd2 = beetlProperties.getDelimiterPlaceholderEnd2();
        if (StringUtils.isNotBlank(delimiterPlaceholderEnd2)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_PLACEHOLDER_END2, delimiterPlaceholderEnd2);
        }
        String delimiterStatementStart2 = beetlProperties.getDelimiterStatementStart2();
        if (StringUtils.isNotBlank(delimiterStatementStart2)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_STATEMENT_START2, delimiterStatementStart2);
        }
        String delimiterStatementEnd2 = beetlProperties.getDelimiterStatementEnd2();
        if (StringUtils.isNotBlank(delimiterStatementEnd2)) {
            properties.setProperty(org.beetl.core.Configuration.DELIMITER_STATEMENT_END2, delimiterStatementEnd2);
        }
        return properties;
    }
}
