package com.gosingapore.common.config.rabbitmq;

import com.gosingapore.common.constants.RabbitMqConstants;
import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.BindingBuilder;
import org.springframework.amqp.core.DirectExchange;
import org.springframework.amqp.core.Queue;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 该类初始化创建队列、交换机，并把队列绑定到交换机
 * 可以定义多个Queue, Exchange
 *
 * @author lsl
 */
@Configuration
public class RabbitQueueAndExchangeConfig {

    @Bean
    public Queue directQueue() {
        return new Queue(RabbitMqConstants.ERP_MESSAGE_QUEUE, true);
    }

    @Bean
    public Queue elasticsearchQueue() {
        return new Queue(RabbitMqConstants.ERP_ES_JOB_QUEUE, true);
    }


    @Bean
    public Queue elasticsearchCustomerQueue() {
        return new Queue(RabbitMqConstants.ERP_ES_CUSTOMER_QUEUE, true);
    }

    /**
     * exchange是交换机交换机的主要作用是接收相应的消息并且绑定到指定的队列.交换机有四种类型,分别为Direct,topic,headers,Fanout.
     * <p>
     * 　　Direct是RabbitMQ默认的交换机模式,也是最简单的模式.即创建消息队列的时候,指定一个BindingKey.当发送者发送消息的时候,指定对应的Key.当Key和消息队列的BindingKey一致的时候,消息将会被发送到该消息队列中.
     * <p>
     * 　　topic转发信息主要是依据通配符,队列和交换机的绑定主要是依据一种模式(通配符+字符串),而当发送消息的时候,只有指定的Key和该模式相匹配的时候,消息才会被发送到该消息队列中.
     * <p>
     * 　　headers也是根据一个规则进行匹配,在消息队列和交换机绑定的时候会指定一组键值对规则,而发送消息的时候也会指定一组键值对规则,当两组键值对规则相匹配的时候,消息会被发送到匹配的消息队列中.
     * <p>
     * 　　Fanout是路由广播的形式,将会把消息发给绑定它的全部队列,即便设置了key,也会被忽略.
     */
    @Bean
    DirectExchange directExchange() {
        return new DirectExchange(RabbitMqConstants.ERP_MESSAGE_EXCHANGE, true, false);
    }

    @Bean
    DirectExchange elasticsearchExchange() {
        return new DirectExchange(RabbitMqConstants.ERP_ES_JOB_EXCHANGE, true, false);
    }

    @Bean
    DirectExchange elasticsearchCustomerExchange() {
        return new DirectExchange(RabbitMqConstants.ERP_ES_CUSTOMER_EXCHANGE, true, false);
    }
    /**
     * 绑定 Queue 和 Exchange
     *
     * @param directQueue    queue
     * @param directExchange exchange
     * @return
     */
    @Bean
    Binding bindingDirectExchange(Queue directQueue, DirectExchange directExchange) {
        return BindingBuilder.bind(directQueue).to(directExchange).with(RabbitMqConstants.ERP_MESSAGE_ROUTING_KEY);
    }

    @Bean
    Binding bindingElasticsearchExchange(Queue elasticsearchQueue, DirectExchange elasticsearchExchange) {
        return BindingBuilder.bind(elasticsearchQueue).to(elasticsearchExchange).with(RabbitMqConstants.ERP_ES_JOB_ROUTING_KEY);
    }

    @Bean
    Binding bindingElasticsearchCustomerExchange(Queue elasticsearchCustomerQueue, DirectExchange elasticsearchCustomerExchange) {
        return BindingBuilder.bind(elasticsearchCustomerQueue).to(elasticsearchCustomerExchange).with(RabbitMqConstants.ERP_ES_CUSTOMER_ROUTING_KEY);
    }
}