package com.gosingapore.common.constants;

/**
 * @author shuyan
 */
public interface RegExpConstants {
    /**
     * 校验手机号必须为纯数字且长度在6-11位之间
     */
    String MOBILE_FORMAT = "^[0-9]{7,11}$";
    /**
     * 校验CPF 长度仅为9或10位且同时包含数字和字母
     */
    String CPF_FORMAT = "^(?=.*\\d)(?=.*[A-Za-z])(\\w{9,10})$";
    /**
     * 校验视频链接，必须以视频格式后缀结尾，扩展以已有格式增加
     */
    String VIDEO = "^https?:\\/\\/.*?(?:swf|avi|flv|mpg|rm|mov|wav|asf|3gp|mkv|rmvb|mp4)$";
    /**
     * 校验图片格式，同上
     */
    String PICTURE = "^https?:\\/\\/.*?(?:gif|png|jpg|jpeg|webp|svg|psd|bmp|tif)$";
    /**
     * 中国手机号
     * 要求: +86 1开头11位
     */
    String CHINA_MOBILE = "^1\\d{10}";
    /**
     * 新加坡手机号
     * 要求: +65 8或9或6 开头 8位
     */
    String SINGAPORE_MOBILE = "^[8,9,6]\\d{7}";
    /**
     * 新加坡手机号和固定电话混合
     * 要求: 固定电话 6开头8位
     */
    String SINGAPORE_FIXED_TELEPHONE = "^[6,8,9]\\d{7}";
    /**
     * 马来西亚手机号
     * 要求: +60  不校验开头数字，手机号位数为9-11位；
     */
    String MALAYSIA_MOBILE = "\\d{9,11}";
    /**
     * 越南手机号
     * 要求: +84  不校验开头数字，手机号位数为9位；
     */
    String VIETNAM_MOBILE = "\\d{9}";
    /**
     * 印度手机号
     * 要求: +91  不校验开头数字，手机号位数为8位；
     */
    String INDIA_MOBILE = "\\d{8}";
    /**
     * 其它国家的手机号
     * 要求:其他区号只校验是数字即可
     */
    String OTHER_COUNTRY_MOBILE = "\\d+";
    /**
     * ipv4
     */
    String IPV4 = "^(\\d|[1-9]\\d|1\\d{2}|2[0-4]\\d|25[0-5])(\\.(\\d|[1-9]\\d|1\\d{2}|2[0-4]\\d|25[0-5])){3}$";
    /**
     * URL合法性校验
     */
    String URL = "^([hH][tT]{2}[pP]:/*|[hH][tT]{2}[pP][sS]:/*|[fF][tT][pP]:/*)(([A-Za-z0-9-~]+).)+([A-Za-z0-9-~/])+(\\??(([A-Za-z0-9-~]+=?)([A-Za-z0-9-~]*)&?)*)$";
    /**
     * Windows下文件名中的无效字符
     */
    String FILE_NAME_INVALID_PATTERN_WIN = "[\\\\/:*?\"<>|]";
    /**
     * 日期
     */
    String DATE_CH = "((19|20)[0-9]{2})-(0?[1-9]|1[012])-(0?[1-9]|[12][0-9]|3[01])";

    /**
     * 文件格式xls
     */
    String XLS_FILE_NAME = "^.+\\.(?i)(xls)$";

    /**
     * 文件格式xlsx
     */
    String XLSX_FILE_NAME = "^.+\\.(?i)(xlsx)$";
}
