package com.gosingapore.common.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 手续办理通知单独写
 * 节日推送和系统维护通知没有加在这里
 * @author zbw
 */
@Getter
@AllArgsConstructor
public enum AppPushNodeEnum {

    /**
     * 第二阶段补充的推送节点
     */
    EMPLOYER_CUSTOMER_REFUSE(false,"邀约反馈", "Invitation feedback", "该求职者已经找到工作，请查看其他求职者信息，我们将继续为您匹配合适人选", "The job applicant has found a job, please check the information of other job applicants, we will continue to match you with suitable job applicants"),
    EMPLOYER_INTERVIEW_FAIL(false,"面试结果通知", "Interview result notification", "求职者XXX未通过面试，请您继续搜索其他适岗人员", "Job applicant XXX failed the interview, please continue to search for other suitable job applicants"),
    EMPLOYER_INTERVIEW_SUCCESS(false,"面试结果通知", "Interview result notification", "亲爱的,您面试的雇员已经面试通过，并开始办理手续,您可以查看他的办理进度哟！", "Dear, the employee you interviewed has passed the interview and started to handle the procedures, you can check his progress!"),
    CUSTOMER_RESUME_REFUSE(false,"投递反馈", "Application feedback", "很抱歉的通知您，您的简历与当前职位不符，请选择其他职位投递", "I’m sorry to inform you that your resume does not match the current position, please choose another position to apply for"),
    CUSTOMER_JOB_INVITE(false,"职位推送通知", "Job push notification", "【新的投递邀请】 JOB_INFO_CH，快看看是否适合您", "[New application invitation] JOB_INFO_EN, quickly see if it suits you"),

    // 雇主邀约工人，现修正为直接推送，跳转页面：到雇主邀约记录
    CUSTOMER_EMPLOYER_INVITE(false,"雇主邀约通知", "Employer invitation notice", "亲爱的，有雇主查看了您的简历,来看看他的职位是否符合你的要求吧.", "Dear, an employer has checked your resume, come to see if his position meets your requirements."),
    // 业务员推荐职位给工人，立即推送给工人，跳转页面：到雇主邀约的顾问推荐列表
    CUSTOMER_BUSINESS_INVITE(false,"顾问推荐通知", "Advisor recommendation notice", "亲爱的，你的顾问为你推荐了新职位，出国工作，机会多多，快来查看吧！", "Dear,your consultant has recommended a new position for you, Come back check it now!"),
    // 工人自己投递/业务帮忙投递成功通知工人，跳转页面：到投递详情页面查看进度
    CUSTOMER_DELIVERY(false,"投递成功通知", "Notification of successful delivery", "亲爱的，你已经成功投递了职位,请注意查看进度！", "Dear, you have successfully delivered your position, please check the progress! And related fees!"),
    // 电文/文员填写/修改面试计划通知工人，跳转页面：到我的面试的那一天看面试计划列表
    CUSTOMER_INTERVIEW(false,"面试安排通知", "Interview Arrangement Notice", "亲爱的，你的顾问发布新的面试计划啦！快来查看吧！面试勿紧张，你是最棒的！狮狮给你加油打气！", "Dear,your consultant has released a new interview plan! Come check it now! Don't be nervous during the interview, you are the best! We will cheer for you!"),
    // 电文/文员点选中通知工人，每天4点以后面试通过的消息不要发给工人，第二天9点发通知，跳转页面：到投递详情查看进度
    CUSTOMER_CHECKED(false,"面试结果通知", "Interview Pass Notification", "亲爱的，恭喜您面试通过！快来查看吧！", "Congratulations on your passing the interview, dear! Check it out!"),
    // 投递流程中，雇主点击同意后，通知工人确认简历，准备面试，跳转页面：到投递详情页面点击确认简历按钮
    CUSTOMER_CONFIRM_RESUME(false,"简历确认通知", "Resume confirmation notice", "亲爱的, 你的顾问帮你优化的简历已被雇主看好,请确认简历,商议面试计划,准备面试吧!","Dear, the resume that your consultant helped you optimize has been optimistic by the employer, please confirm your resume, discuss the interview plan, and prepare for the interview!"),

    // 业务实名认证通知工人，不跳转
    CUSTOMER_VERIFY(false,"实名认证通知", "Real-name authentication notice", "亲爱的，你已通过实名认证，贴心求职顾问服务，诸多优质职位，等你投递!", "Dear,your application has been approved！Exclusive consulting services, Thousands of high-quality positions, Just waiting for you!"),
    // 注册成功通知，不跳转
    CUSTOMER_REGISTER_SUCCESS(true,"注册成功通知", "Notification of successful registration", "亲爱的，恭喜您注册成功，抓紧完善您的个人信息吧！海量高薪工作等您来选！", "Dear, congratulations on your successful registration, and pay close attention to improving your personal information! Massive high-paying jobs are waiting for you to choose!"),

    // 职位审核通过/修改成功，跳转页面：跳转到职位详情页面
    EMPLOYER_JOB_PASS(false,"职位审核通知", "Job review notice", "亲爱的,你的顾问已为你审核/修改了职位信息,继续招聘雇员吧!", "Dear, your consultant has reviewed / modified the job information for you, continue to recruit employees!"),
    // 电文同意某投递，立即通知雇主/负责人，跳转页面：到雇主的应聘详情
    EMPLOYER_ADVISER_RECOMMEND(false,"顾问推荐通知", "Advisor recommendation notice", "亲爱的,你的顾问已为你推荐有意向的雇员,请注意查看是否合适吧！", "Dear, your consultant has recommended potential employees for you, please check to see if it is suitable!"),
    // 电文/文员填写/修改面试计划通知通知雇主/负责人，跳转页面：到我的面试的那一天看面试计划列表
    EMPLOYER_INTERVIEW(false,"面试安排通知", "Interview Arrangement Notice", "亲爱的,你的顾问已安排了合适的面试计划,要按时参加面试哟！", "Dear, your consultant has arranged a suitable interview plan, and you need to attend the interview on time!"),
    // 电文/文员点选中通知雇主/负责人，跳转页面：到投递详情查看进度
    EMPLOYER_CHECKED(false,"面试结果通知", "Interview Pass Notification", "亲爱的,你面试的雇员已经面试通过开始办理手续,你可以查看他的办理进度哟！", "Dear, the employee you interviewed has already passed the interview and started the process, you can check his progress !"),
    // 电文/文员点此单办理完毕，跳转页面：到投递详情查看进度
    EMPLOYER_COMPLETE(false,"办理成功通知", "Successful notification", "亲爱的,你邀请的雇员已经办理完毕,请注意查看!","Dear, the employees you have invited have been processed, please pay attention to check!"),

    // 公司认证通过通知，不跳转
    EMPLOYER_COMPANY_VERIFY(false,"公司认证通知", "Company certification notice", "亲爱的，你的公司已认证通过，贴心招聘顾问服务，诸多优质雇员，等你邀约面试!", "Dear, your company has been certified, intimate recruitment consultant services, many high-quality employees, waiting for you to invite an interview!"),
    // 注册成功通知，不跳转
    EMPLOYER_REGISTER_SUCCESS(true,"注册成功通知", "Notification of successful registration", "亲爱的，恭喜你注册成功，欢迎来到去狮城，狮狮为你配备了专业的招聘顾问，等待你的召唤!", "Dear, congratulations on your successful registration, welcome to \"goSingapore\", we have equipped you with a professional recruitment consultant. Waiting for your call!"),
    ;

    private Boolean pushMust;
    private String chTitle;
    private String enTitle;
    private String chContent;
    private String enContent;
}
