package com.gosingapore.common.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;
import org.springframework.context.i18n.LocaleContextHolder;

/**
 * @author GM
 */

@Getter
@AllArgsConstructor
public enum GsComplainTypeEnum {
    /**
     * QSC：去狮城平台
     * EMP：雇主
     * YW：业务
     * INTER：中介
     * WY：文员
     * DW：电文
     * CUS：工人
     * CP_DW:复合电文
     */
    QSC(0,"去狮城平台","Platform of go Singapore"),
    EMP(1,"雇主","Employer"),
    YW(2,"业务","Business"),
    INTER(3,"中介","Intermediary"),
    WY(4,"文员","Clerk"),
    DW(5,"电文","Telegram"),
    CUS(6,"工人","Worker"),
    CP_DW(7,"复合电文","Compound Telegram");

    private final Integer type;
    private final String name;
    private final String enName;

    /**
     * 根据 type 属性获取 name 属性
     * @param type 要查找的 type 值
     * @return type 对应的 name
     */
    public static String getNameByType(Integer type) {
        if (null == type || type < 0) {
            return null;
        }
        String language = LocaleContextHolder.getLocale().getLanguage();
        for (GsComplainTypeEnum member : GsComplainTypeEnum.values()) {
            if (member.getType().equals(type)) {
                return "en".equals(language) ? member.getEnName() : member.getName();
            }
        }
        return null;
    }

}
