package com.gosingapore.common.enums;

import com.gosingapore.common.constants.RegexPatternConstants;
import com.gosingapore.common.constants.StringContains;
import lombok.AllArgsConstructor;
import lombok.Getter;
import org.apache.commons.lang3.StringUtils;

import java.util.Objects;
import java.util.regex.Pattern;

/**
 * 手机号国家代码
 *
 * @author ZhangJinyu
 * @since 2020-09-16
 */
@Getter
@AllArgsConstructor
public enum MobileCountryEnum {
    /**
     * 其它国家,为系统未收纳的规则
     */
    OTHERS("", RegexPatternConstants.PATTERN_OTHER_COUNTRY_MOBILE, RegexPatternConstants.PATTERN_OTHER_COUNTRY_MOBILE),
    /**
     * 中国
     */
    CHINA("86", RegexPatternConstants.PATTERN_CHINA_MOBILE, RegexPatternConstants.PATTERN_CHINA_MOBILE),
    /**
     * 新加坡
     */
    SINGAPORE("65", RegexPatternConstants.PATTERN_SINGAPORE_MOBILE, RegexPatternConstants.PATTERN_SINGAPORE_FIXED_TELEPHONE),
    /**
     * 马来西亚
     */
    MALAYSIA("60", RegexPatternConstants.PATTERN_MALAYSIA_MOBILE, RegexPatternConstants.PATTERN_MALAYSIA_MOBILE),
    /**
     * 越南
     */
    VIETNAM("84", RegexPatternConstants.PATTERN_VIETNAM_MOBILE, RegexPatternConstants.PATTERN_VIETNAM_MOBILE),
    /**
     * 印度
     */
    INDIA("91", RegexPatternConstants.PATTERN_INDIA_MOBILE, RegexPatternConstants.PATTERN_INDIA_MOBILE),
    ;
    private final String mobileCountryCode;
    private final Pattern mobilePattern;
    private final Pattern fixedTelephonePattern;


    public static MobileCountryEnum getByCode(String mobileCountryCode) {
        if (StringUtils.isBlank(mobileCountryCode)) {
            return OTHERS;
        }
        if (mobileCountryCode.startsWith(StringContains.ADD)) {
            mobileCountryCode = mobileCountryCode.replaceFirst(StringContains.REG_ADD, "");
        }
        for (MobileCountryEnum value : values()) {
            if (value.mobileCountryCode.equalsIgnoreCase(mobileCountryCode)) {
                return value;
            }
        }
        return OTHERS;
    }

    /**
     * 是否有固定电话
     *
     * @return true:有 false:无
     */
    public boolean hasFixedTelephone() {
        return !Objects.isNull(fixedTelephonePattern);
    }

    @Getter
    @AllArgsConstructor
    public static class Mobile {
        private final String mobileCountryCode;
        private final String mobile;
    }
}
