package com.gosingapore.common.enums.financial;

import lombok.AllArgsConstructor;
import lombok.Getter;
import org.springframework.util.ObjectUtils;

/**
 * @author fangqiguang
 * @date 2020/7/28
 */
@AllArgsConstructor
@Getter
public enum FinancialMessageEnum {

    /**
     * 财务消息跳转页
     */
    CHARGE_LIST1(1, 129, null, "charge1-list", "方案1-总收费列表"),
    CHARGE_LIST2(1, 130, null, "charge2-list", "方案2-总收费列表"),

    SERVICE_FEE(2, 129, 1, "service-fee-list", "财务收费-方案1-服务费"),
    DEPOSIT_FEE(2, 129, 2, "deposit-fee-list", "财务收费-方案1-面试保证金"),
    CHINA_FEE(2, 129, 3, "china-fee-list", "财务收费-方案1-中国尾款"),
    SINGAPORE_FEE(2, 129, 4, "singapore-fee-list", "财务收费-方案1-新加坡尾款"),

    SERVICE_CHARGE(2, 130, 1, "service-charge-list", "财务收费-方案2-服务费"),
    REGISTERY_CHARGE(2, 130, 2, "registery-charge-list", "财务收费-方案2-报名费"),
    APPLICATION_CHARGE(2, 130, 3, "application-charge-list", "财务收费-方案2-申请费"),
    CHINA_CHARGE(2, 130, 4, "china-charge-list", "财务收费-方案2-中国尾款"),
    SINGAPORE_CHARGE(2, 130, 5, "singapore-charge-list", "财务收费-方案2-新加坡尾款"),
    ISOLATION_CHARGE(2, 130, 6, "isolation-charge-list", "财务收费-方案2-隔离费"),
    INSPECTION_CHARGE(2, 130, 7, "inspection-charge-list", "财务收费-方案2-检测费"),
    OTHER_CHARGE(2, 130, 8, "other-charge-list", "财务收费-方案2-其他费用"),

    REFUND_CHARGE(3, null, null, "refund-charge-list", "财务-业务退款列表页面"),

    BY_STAGES_CHARGE1(4, 129, null, "by-stages1-charge-list", "财务-方案1分期列表页面"),
    BY_STAGES_CHARGE2(4, 130, null, "by-stages2-charge-list", "财务-方案2分期列表页面"),

    REBATE_CHARGE(5, null, null, "rebate-charge-list", "财务-返利列表页面"),

    WY_REFUND_INTERMEDIARY(6, null, null, "wy-refund-intermediary-list", "文员赔偿中介页面"),

    SALE_AFTER_REFUND(7, null, null, "sale-after-refund-list", "售后退款列表");


    private Integer businessType;
    private Integer chargingScheme;
    private Integer costType;
    private String jumpType;
    private String name;

    public static String getJumpType(Integer businessType, Integer chargingScheme, Integer costType) {
        for (FinancialMessageEnum financialMessageEnum : FinancialMessageEnum.values()) {
            if (ObjectUtils.nullSafeEquals(financialMessageEnum.businessType, businessType) &&
                    ObjectUtils.nullSafeEquals(financialMessageEnum.costType, costType) &&
                    ObjectUtils.nullSafeEquals(financialMessageEnum.chargingScheme, chargingScheme)) {
                return financialMessageEnum.jumpType;
            }
        }
        return null;
    }

}
