package com.gosingapore.common.enums.procedure;

/**
 * 手续办理事项处理状态
 * 办理状态, 0:尚未办理 1:已办理 2:已办理修改
 *
 * @author ZhangJinyu
 * @since 2020-05-12
 */
public enum ResumeProcedureItemProcessingStatusEnum {
    /**
     * 初始状态
     */
    DEFAULT(0),
    /**
     * 已处理
     */
    PROCESSED(1),
    /**
     * 已处理(无需上传)
     */
    PROCESSED_IGNORE(2),
    /**
     * 已处理(修改)
     */
    PROCESSED_MODIFY(3);
    final Integer processingStatus;

    ResumeProcedureItemProcessingStatusEnum(Integer processingStatus) {
        this.processingStatus = processingStatus;
    }

    public static ResumeProcedureItemProcessingStatusEnum get(Integer processingStatus) {
        for (ResumeProcedureItemProcessingStatusEnum value : values()) {
            if (value.processingStatus.equals(processingStatus)) {
                return value;
            }
        }
        return DEFAULT;
    }

    public Integer getValue() {
        return this.processingStatus;
    }

    /**
     * 是否是已处理
     *
     * @return true:已处理 false:待处理
     */
    public boolean isProcessed() {
        return this.equals(PROCESSED) || this.equals(PROCESSED_IGNORE) || this.equals(PROCESSED_MODIFY);
    }
}
