package com.gosingapore.common.event.robot.charge;

import com.cloud.gs.hiring.common.enums.dict.Dict130CostType;
import com.cloud.gs.hiring.common.mapper.customercharge.GsCustomerChargeMapper;
import com.cloud.gs.hiring.common.model.wechat.WeChatRobotResponse;
import com.cloud.gs.hiring.common.properties.ChargeRobotProperties;
import com.gosingapore.common.properties.robot.ChargeAdviceProperties;
import com.gosingapore.common.util.BeetlUtils;
import com.gosingapore.common.util.WeChatRobotSender;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;
import org.springframework.transaction.event.TransactionPhase;
import org.springframework.transaction.event.TransactionalEventListener;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @author : QiWenXiao
 */
@Component
@Slf4j
public class ChargeListener {
    /**
     * 要通知到微信群的收费类型
     */
    @Resource
    private ChargeAdviceProperties chargeAdviceProperties;

    @Resource
    private GsCustomerChargeMapper gsCustomerChargeMapper;

    @Resource
    private ChargeRobotProperties chargeRobotProperties;


    @TransactionalEventListener(value = ChargeEvent.class,phase = TransactionPhase.AFTER_COMMIT)
    @Async
    public void listenChargeEvent(ChargeEvent event) {
        ChargeSource source = (ChargeSource) event.getSource();
        Integer costType = source.getChargeType();
        // 检测此收费的收费类型是否要在微信群里通知
        if (!chargeAdviceProperties.getCostType().contains(costType)) {
            return;
        }
        ChargeRobotWords words = gsCustomerChargeMapper.selectChargeRobotWords(source.getChargeId(), source.getSerialNumber());
        Dict130CostType dict130CostType = Dict130CostType.valueOf(words.getChargeType());
        words.setCostTypePath(dict130CostType.getEnName());
        words.setCostTypeName(dict130CostType.getChName());
        String robotMessage = BeetlUtils.render(chargeRobotProperties.getRobotTemplate(), words);
        for (String webhook : chargeRobotProperties.getWebhooks()) {
            ResponseEntity<WeChatRobotResponse> result = WeChatRobotSender.send(webhook, robotMessage);
            String code = Objects.requireNonNull(result.getBody()).getErrcode();
            if ("0".equals(code)) {
                break;
                // 45009 代表当前 webhook 已经发送20次了，超过了企业微信单分钟的限制
            } else {
                if (!"45009".equals(code)) {
                    log.info("收费群消息推送失败，企业微信返回的错误为{}",result.toString());
                }
            }
        }
    }
}
