package com.gosingapore.common.filter;

import com.gosingapore.common.util.EsCustomerContext;
import com.gosingapore.common.util.EsJobContext;
import com.gosingapore.common.util.MessageRemindContext;
import lombok.extern.slf4j.Slf4j;
import org.apache.tomcat.jni.Local;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.*;
import java.io.IOException;

/**
 * 消息推送过滤器
 *
 * @author shuyan
 */
@Slf4j
@Component
public class MessageRemindFilter implements Filter {

    @Resource
    private MessageRemindContext messageRemindContext;

    @Resource
    private EsJobContext esJobContext;

    @Resource
    private EsCustomerContext esCustomerContext;

    @Override
    public void init(FilterConfig filterConfig) {
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
        try {
            chain.doFilter(request, response);
            try {
                messageRemindContext.sendCache();
            }catch (Exception e){
                log.error("发送erp消息时出现异常", e);
            }
            try {
                esJobContext.sendCache();
            }catch (Exception e){
                log.error("保存职位ES信息时出现异常", e);
            }
            try {
                esCustomerContext.sendCache();
            }catch (Exception e){
                log.error("保存客户ES信息时出现异常", e);
            }
        } finally {
            messageRemindContext.removeContext();
            esJobContext.removeContext();
            esCustomerContext.removeContext();
        }
    }

    @Override
    public void destroy() {
    }
}
