package com.gosingapore.common.model.dto;

import com.gosingapore.common.constants.RoleCodeConstants;
import com.gosingapore.common.enums.dict.Dict66UserJobStatusEnum;
import lombok.Data;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.util.*;

/**
 * The type User details.
 *
 * @author C.K
 * @date 2018 /10/9 10:09 security 用户对象
 */
@Data
public class UserDetailsImpl implements UserDetails {

    private static final long serialVersionUID = -7517169335985544812L;

    private Integer userId;
    private String mobile;
    private String password;
    private Boolean nonLocked;
    private String client;
    private Integer party;
    private Integer orgId;
    private String userName;
    private String name;
    private String alias;
    private String headImg;
    /**
     * 级别 字典106
     */
    private Integer gradeValue;
    /**
     * 入职时间
     */
    private Date entryTime;
    /**
     * 公司id
     */
    private Integer companyId;
    private String companyName;
    /**
     * 组id
     */
    private Integer groupId;
    private String groupName;

    private List<String> roleCodes = new ArrayList<>();
    private List<String> roleCodeNames = new ArrayList<>();
    private Integer departmentId;
    private String departmentName;
    private Boolean isAccountNonExpired;

    /**
     * Instantiates a new User details.
     *
     * @param erpLoginUser the sys user dto
     */
    public UserDetailsImpl(ErpLoginUser erpLoginUser) {
        this.userId = erpLoginUser.getUserId();
        this.mobile = erpLoginUser.getMobile();
        this.nonLocked = !Dict66UserJobStatusEnum.LEAVE.getValue().equals(erpLoginUser.getJobStatusValue());
        this.roleCodes.addAll(erpLoginUser.getRoles());
        this.roleCodeNames.addAll(erpLoginUser.getRoleNames());
        this.password = erpLoginUser.getPassword();
        this.departmentId = erpLoginUser.getDepartmentId();
        this.departmentName = erpLoginUser.getDepartmentName();
        this.isAccountNonExpired = true;
        this.userName = erpLoginUser.getUserName();
        this.name = erpLoginUser.getUserName();
        this.alias = erpLoginUser.getAlias();
        this.headImg=erpLoginUser.getHeadImg();
        this.gradeValue = erpLoginUser.getGradeValue();
        this.entryTime = erpLoginUser.getEntryTime();
        this.companyId = erpLoginUser.getCompanyId();
        this.companyName = erpLoginUser.getCompanyName();
        this.groupId = erpLoginUser.getGroupId();
        this.groupName = erpLoginUser.getGroupName();
    }

    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        List<GrantedAuthority> authorityList = new ArrayList<>();
        for (String roleCode : roleCodes) {
            authorityList.add(new SimpleGrantedAuthority(roleCode));
        }
        authorityList.add(new SimpleGrantedAuthority(RoleCodeConstants.ROLE_USER));
        return authorityList;
    }

    @Override
    public String getPassword() {
        return this.password;
    }

    @Override
    public String getUsername() {
        return this.mobile;
    }

    @Override
    public boolean isAccountNonExpired() {
        return isAccountNonExpired;
    }

    @Override
    public boolean isAccountNonLocked() {
        return nonLocked;
    }

    @Override
    public boolean isCredentialsNonExpired() {
        return true;
    }

    @Override
    public boolean isEnabled() {
        return nonLocked;
    }
}
