package com.gosingapore.common.model.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.cloud.gs.hiring.common.annotation.DictValidate;
import com.gosingapore.common.constants.RegExpConstants;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.ToString;
import lombok.experimental.Accessors;

import javax.validation.constraints.Pattern;
import java.io.Serializable;
import java.time.Instant;

/**
 * @author shuyan
 */
@Data
@Accessors(chain = true)
@ToString
public class GsCpUser implements Serializable {
    private static final long serialVersionUID = 1135563841717363188L;

    @TableId(value = "user_id", type = IdType.AUTO)
    @ApiModelProperty("主键，用户id")
    private Integer userId;

    @ApiModelProperty("用户姓名")
    private String userName;

    @Pattern(regexp = RegExpConstants.MOBILE_FORMAT, message = "请输入正确格式的手机号")
    @ApiModelProperty("电话（登录账号：必须绑定）")
    private String mobile;

    @ApiModelProperty("语言（1：中，2：英）")
    private Integer languageType;

    @ApiModelProperty("电话号区号（50）")
    @DictValidate(50)
    private Integer areaCodeValue;

    @ApiModelProperty("密码")
    private String password;

    @ApiModelProperty("头像")
    private String avatar;

    @ApiModelProperty("背景图")
    private String background;

    @ApiModelProperty("用户email")
    private String email;

    @ApiModelProperty("最近登录时间")
    private Instant lastLoginTime;

    @ApiModelProperty("中介公司id")
    private Integer intermediaryId;

    @ApiModelProperty("第三方授权：微信")
    private String authWeChat;

    @ApiModelProperty("第三方授权：脸书")
    private String authFacebook;

    @ApiModelProperty("第三方授权：qq")
    private String authQq;

    @ApiModelProperty("第三方授权：whats_app")
    private String authWhatsApp;

    @ApiModelProperty("预录入状态 （0：预录入，1：app注册）")
    private Integer advanceStatus;

    @ApiModelProperty("删除标识，关联dict表value")
    private Integer delFlagValue;

    @ApiModelProperty("帐号状态 0：禁用 1：启用")
    private Integer accountStatus;

    @ApiModelProperty("审核状态（默认0：未审核，1：审核通过，2：审核不通过）")
    private Integer auditStatus;

    @ApiModelProperty("审核时间")
    private Instant auditTime;

    @ApiModelProperty("中介登记号")
    private String registrationNumber;

    @ApiModelProperty("等级（106）")
    private Integer gradeValue;

    @ApiModelProperty("创建时间")
    private Instant createTime;

    @ApiModelProperty("更新时间")
    private Instant updateTime;

    @ApiModelProperty("最大库容限制")
    private Integer maximumLimit;

    @ApiModelProperty("出单库库容限制")
    private Integer orderStoreLimit;

    @ApiModelProperty("已批库库容限制")
    private Integer approvedStoreLimit;
}
