package com.gosingapore.common.model.query;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import io.swagger.annotations.ApiParam;
import lombok.ToString;
import org.apache.poi.ss.formula.functions.T;

import java.util.Collections;
import java.util.List;

/**
 * 通用分页请求参数父类
 *
 * @author shuyan
 */
@ToString(callSuper = true)
public class PageQuery implements IPage<T> {
    private static final long serialVersionUID = -3959063150772560757L;
    /**
     * 查询数据列表
     */
    @ApiParam(hidden = true)
    private List<T> records = Collections.emptyList();
    /**
     * 总数，当 total 为 null 或者大于 0 分页插件不在查询总数
     */
    @ApiParam(hidden = true, example = "0")
    private long total = 0;
    /**
     * 每页显示条数，默认 10
     */
    @ApiParam(value = "每页大小", example = "10")
    private long size = 10;
    /**
     * 当前页
     */
    @ApiParam(value = "当前页", example = "1")
    private long current = 1;
    @ApiParam(hidden = true)
    private long pages = 0;

    @Override
    public List<OrderItem> orders() {
        return null;
    }

    @Override
    public List<T> getRecords() {
        return this.records;
    }

    @Override
    public IPage<T> setRecords(List<T> records) {
        this.records = records;
        return this;
    }

    @Override
    public long getTotal() {
        return this.total;
    }

    @Override
    public IPage<T> setTotal(long total) {
        this.total = total;
        return this;
    }

    @Override
    public long getSize() {
        return this.size;
    }

    @Override
    public IPage<T> setSize(long size) {
        this.size = (size < 1)? 10 : size;
        return this;
    }

    @Override
    public long getCurrent() {
        return this.current;
    }

    @Override
    public IPage<T> setCurrent(long current) {
        this.current = (current < 1)? 1 : current;
        return this;
    }
}
