package com.gosingapore.common.model.vo.financial;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @author copying
 * @date 2020-12-31
 * 工人收费
 */
@Data
public class IpaCustomerCharge implements Serializable {

    @ApiModelProperty(name = "收费id",hidden = true)
    private Integer chargeId;

    @ApiModelProperty("工人id")
    private Integer customerId;

    @ApiModelProperty(name = "投递id",hidden = true)
    private Integer resumeId;

    @ApiModelProperty(name = "收费方案codeType=133",hidden = true)
    private Integer chargingScheme;

    /** 业务个人库,业务手动填写的总收费,并非计算得出*/
    @ApiModelProperty("总收费金额")
    private BigDecimal totalCharge;

    @ApiModelProperty("返利")
    private BigDecimal rebate;

    @ApiModelProperty(name = "币种",hidden = true)
    private Integer currency;

    @ApiModelProperty(name = "币种名称",hidden = true)
    private String currencySign;

    /**
     * 129	收款项方案一	1	服务费
     * 129	收款项方案一	2	面试保证金
     * 129	收款项方案一	3	中国尾款
     * 129	收款项方案一	4	新加坡收费
     *
     * 130	收款项方案二	1	服务费
     * 130	收款项方案二	2	报名费
     * 130	收款项方案二	3	申请费
     * 130	收款项方案二	4	中国尾款
     *
     * 130	收款项方案二	5	新加坡尾款
     *
     * 130	收款项方案二	6	隔离费
     * 130	收款项方案二	7	检测费
     * 130	收款项方案二	8	其他费用*/
    @ApiModelProperty(name = "收费类型",hidden = true)
    private Integer costType;

    @ApiModelProperty(name = "收费金额",hidden = true)
    private Double collectAmount;

    /** 计算后带符号回显 (129:1+2+3)(130:1+2+3+4)*/
    @ApiModelProperty("中国收费")
    private String chCharge;

    /** 计算后带符号回显 (129:4)(130:5)*/
    @ApiModelProperty("马来收费")
    private String mlCharge;

    @Override
    public String toString() {
        return "总收费金额=" + totalCharge +
                ", 返利=" + rebate +
                ", 中国收费=" + chCharge +
                ", 马来收费=" + mlCharge ;
    }
}
