package com.gosingapore.common.processor;

import com.alibaba.druid.support.http.StatViewServlet;
import com.alibaba.druid.util.Utils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * @author shuyan
 * @date 2020/8/5 9:40
 */
@Component
public class HiringStatViewServlet extends StatViewServlet {
    private static final long serialVersionUID = 3965736412484429103L;

    private static final String DOT_HTML = ".html";
    private static final String DOT_JPG = ".jpg";
    private static final String DOT_CSS = ".css";
    private static final String DOT_JS = ".js";
    private static final String SUBMIT_LOGIN = "/submitLogin";
    private static final String SLASH = "/";

    @Value("${spring.application.name}")
    private String applicationName;

    @Override
    protected void returnResourceFile(String fileName, String uri, HttpServletResponse response) throws IOException {
        String filePath = getFilePath(fileName);

        if (filePath.endsWith(DOT_HTML)) {
            response.setContentType("text/html; charset=utf-8");
        }
        if (fileName.endsWith(DOT_JPG)) {
            byte[] bytes = Utils.readByteArrayFromResource(filePath);
            if (bytes != null) {
                response.getOutputStream().write(bytes);
            }

            return;
        }

        String text = Utils.readFromResource(filePath);
        if (text == null) {
            response.sendRedirect(uri + "/index.html");
            return;
        }
        if (fileName.endsWith(DOT_CSS)) {
            response.setContentType("text/css;charset=utf-8");
        } else if (fileName.endsWith(DOT_JS)) {
            response.setContentType("text/javascript;charset=utf-8");
        }
        response.getWriter().write(text);
    }

    @Override
    public void service(HttpServletRequest request, HttpServletResponse response) throws IOException {
        String contextPath = request.getContextPath();
        String servletPath = request.getServletPath();
        String requestUri = request.getRequestURI();

        response.setCharacterEncoding("utf-8");

        // root context
        if (contextPath == null) {
            contextPath = "";
        }
        String uri = contextPath + servletPath;
        String path = requestUri.substring(contextPath.length() + servletPath.length());

        if (!isPermittedRequest(request)) {
            path = "/nopermit.html";
            returnResourceFile(path, uri, response);
            return;
        }

        if (SUBMIT_LOGIN.equals(path)) {
            String usernameParam = request.getParameter(PARAM_NAME_USERNAME);
            String passwordParam = request.getParameter(PARAM_NAME_PASSWORD);
            if (username.equals(usernameParam) && password.equals(passwordParam)) {
                request.getSession().setAttribute(SESSION_USER_KEY, username);
                response.getWriter().print("success");
            } else {
                response.getWriter().print("error");
            }
            return;
        }

        boolean pathFlag = "/login.html".equals(path) || path.startsWith("/css") || path.startsWith("/js") || path.startsWith("/img");
        if (isRequireAuth()
                && !ContainsUser(request)
                && !checkLoginParam(request)
                && !pathFlag) {
            if (contextPath.isEmpty() || SLASH.equals(contextPath)) {
                response.sendRedirect("/" + applicationName + "/druid/login.html");
            } else {
                if ("".equals(path)) {
                    response.sendRedirect(applicationName + "/druid/login.html");
                } else {
                    response.sendRedirect(applicationName + "/login.html");
                }
            }
            return;
        }

        if ("".equals(path)) {
            if (contextPath.isEmpty() || SLASH.equals(contextPath)) {
                response.sendRedirect("/" + applicationName + "/druid/index.html");
            } else {
                response.sendRedirect(applicationName + "/druid/index.html");
            }
            return;
        }

        if (SLASH.equals(path)) {
            response.sendRedirect(applicationName + "/index.html");
            return;
        }

        if (path.contains(".json")) {
            String fullUrl = path;
            if (request.getQueryString() != null && request.getQueryString().length() > 0) {
                fullUrl += "?" + request.getQueryString();
            }
            response.getWriter().print(process(fullUrl));
            return;
        }

        // find file in resources path
        returnResourceFile(path, uri, response);
    }
}
