package com.gosingapore.common.start;

import com.alibaba.fastjson.JSONObject;
import com.gosingapore.common.constants.ServiceStartConstants;
import org.apache.commons.lang3.StringUtils;
import org.springframework.data.redis.core.HashOperations;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.RequestEntity;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponentsBuilder;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

/**
 * @author ZhangJinyu
 * @since 2020-10-02
 */
public class ServiceStartService {
    private final RedisTemplate<String, Object> stringListRedisTemplate;
    private static final String DEV = "dev";
    private static final String TEST = "test";
    private static final String PRO = "pro";

    public ServiceStartService(RedisTemplate<String, Object> stringListRedisTemplate) {
        this.stringListRedisTemplate = stringListRedisTemplate;
    }

    public void started(String environment, String applicationName, String url) {
        if (StringUtils.isBlank(url)) {
            return;
        }
        String env = "";
        if (StringUtils.containsIgnoreCase(environment, DEV)) {
            return;
        }
        if (StringUtils.containsIgnoreCase(environment, TEST)) {
            env = "测试";
        }
        if (StringUtils.containsIgnoreCase(environment, PRO)) {
            env = "生产";
        }
        try {
            if (StringUtils.isNotBlank(applicationName)) {
                HashOperations<String, String, StartInfo> opsForHash = stringListRedisTemplate.opsForHash();
                StartInfo startInfo = opsForHash.get(ServiceStartConstants.SERVICE_START_INFO, applicationName);
                Date date = new Date();
                if (Objects.isNull(startInfo)) {
                    startInfo = new StartInfo();
                    startInfo.setServiceName(applicationName);
                    startInfo.setStartTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(date));
                    startInfo.setLastTime(startInfo.getStartTime());
                    startInfo.setStartCount(1);
                } else {
                    startInfo.setLastTime(startInfo.getStartTime());
                    startInfo.setStartTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(date));
                    startInfo.setStartTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(date));
                    startInfo.setStartCount(startInfo.getStartCount() + 1);
                }
                opsForHash.put(ServiceStartConstants.SERVICE_START_INFO, applicationName, startInfo);
                stringListRedisTemplate.expire(ServiceStartConstants.SERVICE_START_INFO, 8, TimeUnit.HOURS);

                String text = ">**服务名**:%s \n**本次启动时间**:%s \n**上次启动时间**:%s \n**启动次数**:%s";
                String stringBuilder = "> **环境**:" + env + "\n" + "> 报告服务:" + applicationName +
                        "\n" +
                        String.format(text, applicationName, startInfo.getStartTime(), startInfo.getLastTime(), startInfo.getStartCount()) +
                        "\n\n\n ";
                report2Wx(url, stringBuilder);
            }
        } catch (Exception ignore) {
            ignore.printStackTrace();
        }
    }

    private void report2Wx(String url, String content) {
        JSONObject markdown = new JSONObject();
        markdown.put("content", content);
        JSONObject body = new JSONObject();
        body.put("msgtype", "markdown");
        body.put("markdown", markdown);
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.setContentType(MediaType.APPLICATION_JSON);
        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(url);
        RequestEntity<?> request = new RequestEntity<>(body.toJSONString(), httpHeaders, HttpMethod.POST, builder.build().toUri());
        new RestTemplate().exchange(request, JSONObject.class);
    }

}
