package com.gosingapore.common.util;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.beust.jcommander.internal.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import java.lang.reflect.Field;
import java.util.*;

/**
 * @author copying
 * @version 3.0
 * @date 2021/3/5 10:30
 *
 * 复制对象的工具
 */
@Component
public class BeanUtil {

    private BeanUtil(){}
    public static Map<String, Object> convertToMap(Object obj) {
        return convertToMap(obj, false);
    }
    public static Map<String, Object> convertToMap(Object obj, boolean convertNull) {
        if(obj == null){
            return null;
        }
        Map<String, Object> map = new HashMap<>();
        Field[] declaredFields = obj.getClass().getDeclaredFields();
        for (Field field : declaredFields) {
            field.setAccessible(true);
            try {
                Object o = field.get(obj);
                if (Objects.nonNull(o)){
                    if (o instanceof Collection) {
                        if (((Collection)o).size()==0){
                            continue;
                        }
                    } else if (o instanceof Map) {
                        if (((Map) o).size() == 0) {
                            continue;
                        }
                    } else if (o instanceof Enum) {
                        o = ((Enum) o).name();
                    }
                    map.put(field.getName(), o);
                }
                else if(convertNull) {
                    map.put(field.getName(), null);
                }

            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return map;
    }

    /**
     * 复制集合
     * 注: 输出类型对象 必须有无参构造器
     * @param input 输入集合
     * @param out  输出集合类型
     * @param <E>   输入集合类型
     * @param <T>   输出集合类型
     * @return 返回集合
     */
    public static <E, T> List<T> copyPropertiesList(List<E> input, Class<T> out) {
        List<T> output = Lists.newArrayList();
        if (CollectionUtils.isNotEmpty(input)) {
            for (E source : input) {
                T target = BeanUtils.instantiateClass(out);
                BeanUtils.copyProperties(source, target);
                output.add(target);
            }
        }
        return output;
    }

    /**
     * 复制对象
     * 注: 输出类型对象 必须有无参构造器
     * @param input 输入对象
     * @param out 输出对象类型
     * @param <E> 输入对象类型
     * @param <T> 输出对象类型
     * @return 返回对象
     */
    public static <E, T> T copyProperties(E input, Class<T> out){
        T target = BeanUtils.instantiateClass(out);
        if (Objects.nonNull(input)){
            BeanUtils.copyProperties(input, target);
        }
        return target;
    }
}
