package com.gosingapore.common.util;

import org.beetl.core.GroupTemplate;
import org.beetl.core.Template;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.Map;

/**
 * @author: QiWenXiao
 */
@Component
public class BeetlUtils {

    private static GroupTemplate gt;
    @Qualifier("groupTemplate")
    @Resource
    private GroupTemplate groupTemplate;

    /**
     * 将模板渲染和模板参数渲染成想要的字符串结果
     * @param templateStr 模板
     * @param dataMap 模板参数，Map 类型
     * @return 结果
     */
    public static String render(String templateStr, Map<String, Object> dataMap) {
        if (StringUtils.hasLength(templateStr)) {
            Template template = gt.getTemplate(templateStr);
            template.binding(dataMap);
            return template.render();
        }
        return null;
    }
    /**
     * 将模板渲染和模板参数渲染成想要的字符串结果
     * @param templateStr 模板
     * @param data 模板参数，任意 类型
     * @return 结果
     */
    public static String render(String templateStr, Object data) {
        return render(templateStr, BeanUtil.convertToMap(data));
    }

    /**
     * 获取 Template 类的实例并预绑定一些参数
     * @param templateStr 模板
     * @param dataMap 模板参数
     * @return 结果
     */
    public static Template getTemplate(String templateStr, Map<String, Object> dataMap){
        Template template = gt.getTemplate(templateStr);
        template.binding(dataMap);
        return template;
    }
    /**
     * 获取 Template 类的实例并预绑定一些参数
     * @param templateStr 模板
     * @param data 模板参数
     * @return 结果
     */
    public static Template getTemplate(String templateStr, Object data){
        Template template = gt.getTemplate(templateStr);
        template.binding(BeanUtil.convertToMap(data));
        return template;
    }

    /**
     * 根据模板获取 Template 实例，不绑定任何参数
     * @param templateStr 模板
     * @return 结果
     */
    public static Template getTemplate(String templateStr) {
        return gt.getTemplate(templateStr);
    }
    @PostConstruct
    public void initGroupTemplate() {
        gt = groupTemplate;
    }
}
