package com.gosingapore.common.util;

import com.alibaba.fastjson.JSONArray;
import com.gosingapore.common.constants.RabbitMqConstants;
import com.gosingapore.common.model.dto.SyncCustomer;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * ES 客户消息 上下文
 * @author lsl
 * @date 2021-04-20 10:16
 */
@Slf4j
@Component
@SuppressWarnings("unused")
public class EsCustomerContext {
    /**
     * 线程安全
     */
    private static ThreadLocal<ContextCache> context = ThreadLocal.withInitial(ContextCache::new);

    @Resource
    private RabbitTemplate rabbitTemplate;

    public void saveCustomer(SyncCustomer syncCustomer) {
        EsCustomerContext.ContextCache contextCache = context.get();
        List<SyncCustomer> syncCustomerListy = contextCache.getSyncCustomerList();
        syncCustomerListy.add(syncCustomer);
    }

    public void sendCache() {
        List<SyncCustomer> syncCustomerList = context.get().getSyncCustomerList();
        if (!CollectionUtils.isEmpty(syncCustomerList)) {
            rabbitTemplate.convertAndSend(RabbitMqConstants.ERP_ES_CUSTOMER_QUEUE, JSONArray.toJSONString(syncCustomerList));
            log.info("成功保存 {} 条客户信息", syncCustomerList.size());
        }
    }


    public void clearCache() {
        EsCustomerContext.ContextCache contextCache = context.get();
        contextCache.getSyncCustomerList().clear();
    }

    public void removeContext() {
        context.remove();
    }

    @Data
    private static class ContextCache {
        /**
         * 缓存所有消息
         */
        private List<SyncCustomer> syncCustomerList = new ArrayList<>();
    }
}
