package com.gosingapore.common.util;

import com.alibaba.fastjson.JSONArray;
import com.gosingapore.common.constants.RabbitMqConstants;
import com.gosingapore.common.model.dto.SyncJob;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * ES job消息 上下文
 * @author lsl
 * @date 2021-04-15 10:16
 */
@Slf4j
@Component
@SuppressWarnings("unused")
public class EsJobContext {
    /**
     * 线程安全
     */
    private static ThreadLocal<ContextCache> context = ThreadLocal.withInitial(ContextCache::new);

    @Resource
    private RabbitTemplate rabbitTemplate;

    public void saveJob(SyncJob syncJob) {
        EsJobContext.ContextCache contextCache = context.get();
        List<SyncJob> syncJobList = contextCache.getSyncJobList();
        syncJobList.add(syncJob);
    }

    public void sendCache() {
        List<SyncJob> jobIdList = context.get().getSyncJobList();
        if (!CollectionUtils.isEmpty(jobIdList)) {
            rabbitTemplate.convertAndSend(RabbitMqConstants.ERP_ES_JOB_QUEUE, JSONArray.toJSONString(jobIdList));
            log.info("成功保存 {} 条职位信息", jobIdList.size());
        }
    }


    public void clearCache() {
        EsJobContext.ContextCache contextCache = context.get();
        contextCache.getSyncJobList().clear();
    }

    public void removeContext() {
        context.remove();
    }

    @Data
    private static class ContextCache {
        /**
         * 缓存所有消息
         */
        private List<SyncJob> syncJobList = new ArrayList<>();
    }
}
