package com.gosingapore.common.util;

import com.gosingapore.common.constants.RegexPatternConstants;
import com.gosingapore.common.constants.StringContains;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.HashSet;
import java.util.Set;

/**
 * 文件后缀工具类
 *
 * @author ZhangJinyu
 * @since 2020-09-29
 */
public class FileSuffixUtil {

    /**
     * url是否包含指定的后缀
     *
     * @param fileUrl  文件的url
     * @param suffixes 后缀
     * @return 是否包含  true:包含;false:不包含
     */
    public static boolean fileUrlContainSuffix(String fileUrl, String... suffixes) {
        if (ArrayUtils.isEmpty(suffixes)) {
            return true;
        }
        if (StringUtils.isBlank(fileUrl)) {
            return false;
        }
        if (RegexPatternConstants.PATTERN_URL.matcher(fileUrl).matches()) {
            Set<String> fileSuffixes = new HashSet<>(suffixes.length);
            for (String suffix : suffixes) {
                String result = StringUtils.contains(suffix, StringContains.DOT) ? FileNameUtil.getSuffix(suffix) : suffix;
                if (StringUtils.isNotBlank(result)) {
                    fileSuffixes.add(result.toLowerCase());
                }
            }
            String suffix = FileNameUtil.getSuffix(fileUrl);
            return fileSuffixes.contains(suffix.toLowerCase());
        }
        return false;
    }
}
