package com.gosingapore.common.util;

import com.alibaba.fastjson.JSONObject;
import com.cloud.gs.hiring.base.util.ResponseCode;
import com.gosingapore.common.exception.CustomizeException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;
import org.springframework.web.client.RestTemplate;

import java.util.Map;

/**
 * rest调用工具类
 * @author lsl
 * @date 2021-04-28 16:24
 */
@Component
public class RestUtil {

    private static final RestTemplate restTemplate = new RestTemplate();
    private static final String ERR_CODE_KEY = "errcode";
    private static final Integer ERR_CODE_SUCCESS = 0;
    /**
     * get请求
     * @param url 请求的url
     * @param param 请求参数
     * @return
     */
    public JSONObject restGet(String url,Map<String,Object> param){
        return request(url, param,HttpMethod.GET);
    }

    /**
     * Post请求
     * @param url 请求的url
     * @param param 请求参数
     * @return
     */
    public JSONObject restPost(String url,Map<String,Object> param){
        return request(url, param,HttpMethod.POST);

    }


    /**
     * 执行请求
     * @param url 请求的url
     * @param param 请求参数
     * @param httpMethod 请求方式
     * @return
     */
    private JSONObject request(String url, Map<String,Object> param, HttpMethod httpMethod) {
        ResponseEntity<JSONObject> response;
        try {
            if (StringUtils.isEmpty(url)) {
                throw new IllegalArgumentException();
            }
            HttpEntity<Map<String,Object>> requestEntity = new HttpEntity<>(param);
            response = restTemplate.exchange(url, httpMethod, requestEntity, JSONObject.class);
        }catch (Exception ex){
            ex.printStackTrace();
            return new JSONObject();
        }

        return response.getBody();
    }

    /**
     * 获取token
     * @param url 请求的url
     * @param corpId 请求参数
     * @param secret 请求参数
     * @return
     */
    public String getToken(String url, String corpId, String secret) {
        RestTemplate restTemplate = new RestTemplate();
        JSONObject response = restTemplate.getForObject(url, JSONObject.class, corpId, secret);
        if (response != null && response.getIntValue(ERR_CODE_KEY) == ERR_CODE_SUCCESS) {
            return response.getString("access_token");
        } else {
            throw new CustomizeException(ResponseCode.SYS_INTERNAL_SERVER_ERROR, "获取 access_token 失败", "Failed to get access_token");
        }
    }

}
