package com.gosingapore.common.util.excel;

import org.apache.poi.hssf.usermodel.*;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import java.util.Map;

/**
 * @author 白海波
 * @date 2020/7/2 12:35
 */
@Component
public class ExcelUtil {

    /**
     * 导出Excel
     *
     * @param sheetName sheet名称
     * @param title     标题
     * @param values    内容
     * @param wb        HSSFWorkbook对象
     * @return 结果
     */
    public static HSSFWorkbook getHSSFWorkbook(String sheetName, String[] title, String[][] values, HSSFWorkbook wb) {

        // 第一步，创建一个HSSFWorkbook，对应一个Excel文件
        if (wb == null) {
            wb = new HSSFWorkbook();
        }

        // 第二步，在workbook中添加一个sheet,对应Excel文件中的sheet
        HSSFSheet sheet = wb.createSheet(sheetName);
        // 第三步，在sheet中添加表头第0行,注意老版本poi对Excel的行数列数有限制
        HSSFRow row = sheet.createRow(0);
        //字体
        HSSFFont font = wb.createFont();
        font.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
        font.setFontHeightInPoints((short) 12);
        // 第四步，创建单元格，并设置值表头 设置表头居中
        HSSFCellStyle style = wb.createCellStyle();
        //边框
        style.setBorderBottom(HSSFCellStyle.BORDER_THIN);
        style.setBorderLeft(HSSFCellStyle.BORDER_THIN);
        style.setBorderTop(HSSFCellStyle.BORDER_THIN);
        style.setBorderRight(HSSFCellStyle.BORDER_THIN);
        // 水平居中
        style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
        style.setFont(font);
        //标题行背景色
        style.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
        style.setFillPattern(HSSFCellStyle.SOLID_FOREGROUND);

        //标题列对象
        HSSFCell cell;

        //创建标题
        for (int i = 0; i < title.length; i++) {
            cell = row.createCell(i);
            cell.setCellValue(title[i]);
            cell.setCellStyle(style);
        }
        //内容列对象
        HSSFCell contentCell;
        //内容列样式
        HSSFCellStyle contentStyle = wb.createCellStyle();
        //边框
        contentStyle.setBorderBottom(HSSFCellStyle.BORDER_THIN);
        contentStyle.setBorderLeft(HSSFCellStyle.BORDER_THIN);
        contentStyle.setBorderTop(HSSFCellStyle.BORDER_THIN);
        contentStyle.setBorderRight(HSSFCellStyle.BORDER_THIN);
        //水平居中
        contentStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);
        //垂直居中
        contentStyle.setVerticalAlignment(CellStyle.VERTICAL_CENTER);
        //创建内容
        for (int i = 0; i < values.length; i++) {
            row = sheet.createRow(i + 1);
            for (int j = 0; j < values[i].length; j++) {
                //将内容按顺序赋给对应的列对象
                contentCell = row.createCell(j);
                contentCell.setCellValue(values[i][j]);
                contentCell.setCellStyle(contentStyle);
            }
        }
        return wb;
    }

    public static String[] getTitle() {
        String[] titles = {};
        titles = new String[]{"客户ID", "姓名", "区号","电话", "国籍", "证件类型", "证件号码", "出生日期", "年龄",
                "性别", "婚姻状况", "英语能力", "身高", "体重","籍贯","现住址","期望职位","期望薪资最大值（新币）",
        "期望薪资最小值（新币）","期望工作地点","求职状态","技能","工作经历","教育经历","个人简介","客户资料"};
        return titles;
    }

    /**
     * @author gcl
     * 输出excel
     * @param map 内容
     * @param response 响应
     */
    public static void outputWorkbook(Map<String, Object> map, HttpServletResponse response){
        //创建HSSFWorkbook
        HSSFWorkbook wb = ExcelUtil.getHSSFWorkbook((String) map.get("sheetName"), (String[]) map.get("title"), (String[][]) map.get("content"), null);
        //响应到客户端
        try {
            response.setCharacterEncoding("utf-8");
            response.setContentType("application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + map.get("fileName"));
            response.addHeader("Pargam", "no-cache");
            response.addHeader("Cache-Control", "no-cache");
            OutputStream os = response.getOutputStream();
            wb.write(os);
            os.flush();
            os.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
