package com.gosingapore.common.util.job;

import com.alibaba.fastjson.JSONObject;
import com.gosingapore.common.model.dto.RobotDeclarationDTO;
import com.cloud.gs.hiring.common.model.wechat.WeChatRobotResponse;
import com.gosingapore.common.properties.robot.RobotDeclarationProperties;
import com.gosingapore.common.util.BeetlUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.http.*;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponentsBuilder;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * 发送报单消息到企业微信
 * @author lsl
 * @date 2020/11/24
 */
@Component
@Slf4j
public class RobotDeclarationUtil {

    /**
     * 调用企业微信机器人接口
     **/
    private static final RestTemplate REST_TEMPLATE = new RestTemplate();

    @Resource
    private RobotDeclarationProperties robotDeclarationProperties;

    @Resource
    private RedisTemplate<String,Integer> redisTemplate;

    /**
     * 获取中国模板消息
     * flag 1 业务 2电文
     * @return
     */
    public String getChFormWorkContent(RobotDeclarationDTO robotDeclarationDTO,Integer flag){
        String template = robotDeclarationProperties.getChDeclarationTemplate();
        if(flag == 1){
            robotDeclarationDTO.setUrl(robotDeclarationProperties.getErpChYwUrl());
        }else{
            //一手单
            if(robotDeclarationDTO.getJobType() == 1 || robotDeclarationDTO.getJobType() == 2){
                //中国业务
                if(robotDeclarationDTO.getCountryValue() == 1){
                    robotDeclarationDTO.setUrl(robotDeclarationProperties.getErpChDwUrl());
                }else if(robotDeclarationDTO.getCountryValue() == 4){
                    robotDeclarationDTO.setUrl(robotDeclarationProperties.getErpYnDwUrl());
                }
            }else{
                robotDeclarationDTO.setUrl(robotDeclarationProperties.getCpUrl());
            }
        }

        robotDeclarationDTO.setRandomNum(System.currentTimeMillis());
        return BeetlUtils.render(template,robotDeclarationDTO);
    }

    /**
     * 获取马来模板消息  1业务 2电文
     * @return String
     */
    public String getMlFormWorkContent(RobotDeclarationDTO robotDeclarationDTO,int flag){
        String template = robotDeclarationProperties.getMlDeclarationTemplate();

        if(flag == 1){
            robotDeclarationDTO.setUrl(robotDeclarationProperties.getErpChYwUrl());
        }else{
            //一手单
            if(robotDeclarationDTO.getJobType() == 1 || robotDeclarationDTO.getJobType() == 2){
                robotDeclarationDTO.setUrl(robotDeclarationProperties.getErpChYwUrl());
            }else{
                robotDeclarationDTO.setUrl(robotDeclarationProperties.getCpUrl());
            }
        }
        robotDeclarationDTO.setRandomNum(System.currentTimeMillis());
        return BeetlUtils.render(template,robotDeclarationDTO);
    }

    /**
     * 发送报单消息到马来群
     * @param robotDeclarationDTO
     */
    public void sendGroup(RobotDeclarationDTO robotDeclarationDTO){

        //业务群
        List<String> YwDeclarationList = new ArrayList<>();
        //电文群
        List<String> DwDeclarationList = new ArrayList<>();

        //1中国  2马来
        if(robotDeclarationDTO.getUserRole() == 1){
            YwDeclarationList = robotDeclarationProperties.getChYwDeclaration();
            DwDeclarationList = robotDeclarationProperties.getChDwDeclaration();


            //一天最多发两次 判断今天发了几次
            Integer count = redisTemplate.opsForValue().get("send:ch:"+robotDeclarationDTO.getJobId()+","+robotDeclarationDTO.getCustomerId());

            if(count == null){
                count = 0;
            }
            if(count < 2){
                Integer sendCount = redisTemplate.opsForValue().get("send:ch:count");
                if(sendCount == null){
                    sendCount = 0;
                }
                sendCount += 1;
                Long expiresTime = getSecondsNextEarlyMorning();
                redisTemplate.opsForValue().set("send:ch:count",sendCount,expiresTime, TimeUnit.SECONDS);


                robotDeclarationDTO.setTodayBillingCount(sendCount);
                //消息模板
                String ywContent = getChFormWorkContent(robotDeclarationDTO,1);
                //中国业务
                boolean chYwBool = doSend(YwDeclarationList,ywContent,0);

                String dwContent = getChFormWorkContent(robotDeclarationDTO,2);
                //中国电文
                boolean chDwBool = doSend(DwDeclarationList,dwContent,0);

                if(!chYwBool){
                    log.info("发送中国业务企业微信群，无可用机器人");
                }
                if(!chDwBool){
                    log.info("发送中国电文企业微信群，无可用机器人");
                }
                if(chYwBool && chDwBool){
                    //记录一次发送次数
                    count = count + 1;
                    redisTemplate.opsForValue().set("send:ch:"+robotDeclarationDTO.getJobId()+","+robotDeclarationDTO.getCustomerId(),count,expiresTime, TimeUnit.SECONDS);
                }
            }else {
                log.info("今日发送消息次数已达上线");
                return;
            }

        }else if(robotDeclarationDTO.getUserRole() == 2){

            YwDeclarationList = robotDeclarationProperties.getMlYwDeclaration();
            DwDeclarationList = robotDeclarationProperties.getMlDwDeclaration();

            //一天最多发两次 判断今天发了几次
            Integer count = redisTemplate.opsForValue().get("send:ml:"+robotDeclarationDTO.getJobId()+","+robotDeclarationDTO.getCustomerId());
            if(count == null){
                count = 0;
            }

            if(count < 2){

                Integer sendCount = redisTemplate.opsForValue().get("send:ml:count");
                if(sendCount == null){
                    sendCount = 0;
                }
                sendCount += 1;
                Long expiresTime = getSecondsNextEarlyMorning();
                redisTemplate.opsForValue().set("send:ml:count",sendCount,expiresTime, TimeUnit.SECONDS);

                robotDeclarationDTO.setTodayBillingCount(sendCount);

                //消息模板
                String ywContent = getMlFormWorkContent(robotDeclarationDTO,1);
                //马来业务
                boolean mlYwBool = doSend(YwDeclarationList,ywContent,0);

                String mlContent = getMlFormWorkContent(robotDeclarationDTO,2);
                //马来电文
                boolean mlDwBool = doSend(DwDeclarationList,mlContent,0);

                if(!mlYwBool){
                    log.info("发送马来业务企业微信群，无可用机器人");
                }
                if(!mlDwBool){
                    log.info("发送马来电文企业微信群，无可用机器人");
                }
                if(mlYwBool && mlDwBool){
                    //记录一次发送次数
                    count = count + 1;
                    redisTemplate.opsForValue().set("send:ml:"+robotDeclarationDTO.getJobId()+","+robotDeclarationDTO.getCustomerId(),count,expiresTime, TimeUnit.SECONDS);
                }
            }else {
                log.info("今日发送消息次数已达上线");
                return;
            }
        }
    }

    public boolean doSend(List<String> urlList, String content,Integer item) {

        if(item + 1 > urlList.size()){
            return false;
        }
        JSONObject markdown = new JSONObject();
        markdown.put("content", content);
        JSONObject body = new JSONObject();
        body.put("msgtype", "markdown");
        body.put("markdown", markdown);
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.setContentType(MediaType.APPLICATION_JSON);
        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(urlList.get(item));
        RequestEntity<?> request = new RequestEntity<>(body.toJSONString(), httpHeaders, HttpMethod.POST, builder.build().toUri());
        // 企业微信返回的状态码
        ResponseEntity<WeChatRobotResponse> robotResponse = REST_TEMPLATE.exchange(request, WeChatRobotResponse.class);
        String errCode = "0";
        try {
            errCode = robotResponse.getBody().getErrcode();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("调用企业微信机器人发生异常");
        }
        //如果发送失败 切换机器人
        if("0".equals(errCode)){
            //发送成功 记一次次数
            return true;
        }else if("45009".equals(errCode)){
            doSend(urlList,content,item+1);
        }
        return false;
    }

    /**
     * 判断当前时间距离第二天凌晨的秒数
     *
     * @return 返回值单位为[s:秒]
     */
    public  Long getSecondsNextEarlyMorning() {
        Calendar cal = Calendar.getInstance();
        cal.add(Calendar.DAY_OF_YEAR, 1);
        cal.set(Calendar.HOUR_OF_DAY, 0);
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MINUTE, 0);
        cal.set(Calendar.MILLISECOND, 0);
        return (cal.getTimeInMillis() - System.currentTimeMillis()) / 1000;
    }

}
