package com.gosingapore.common.util.job;

import com.gosingapore.common.enums.dict.Dict107JobTypeEnum;
import com.gosingapore.common.util.BeetlUtils;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.experimental.Accessors;
import org.beetl.core.Template;

import java.math.BigDecimal;
import java.util.List;


/**
 * 职位上线时，企业微信机器人的话术
 *
 * @author: QiWenXiao
 */
@Data
@Accessors(chain = true)
public class RobotOfJobOnlineWords {
    private static final String LINE_SEPARATOR = "\n";
    /**
     * 职位发布者姓名，就是登录者的姓名，从 UserUtil中取
     */
    private String jobPublisherName;
    /**
     * 职位ID
     */
    private Integer jobId;
    /**
     * 职位类型
     */
    private Integer jobType;
    /**
     * 职位名称
     */
    private String jobName;

    /**
     * 伙伴中介单子的收费
     */
    private List<Charge> intermediaryCharges;

    /**
     * 自营单子的收费
     */
    private BigDecimal charge;

    /**
     * 原单描述
     */
    private String remark;

    /**
     * 图片和视频的路径
     */
    private List<String> mediaUrlList;

    private String url;

    /**
     * 是否是新单
     */
    private Boolean newOrder;

    /**
     * 国籍
     */
    private String country;

    /**
     * 单子类型
     */
    private String typeName;

    /**
     * 发单数量
     */
    private Integer count;

    /**
     * 将机器人的发送的内容编辑成 markdown 格式
     * @param template markdown 消息模板
     * @return markdown格式的消息
     */
    public String toMarkdown(String template) {
        Template t = BeetlUtils.getTemplate(template,this);
        t.binding("isSelf",isSelf());
        return t.render();
    }

    private boolean isSelf() {
        Integer selfStandardValue = Dict107JobTypeEnum.SELF_STANDARD.getValue();
        Integer selfNonstandardValue = Dict107JobTypeEnum.SELF_NONSTANDARD.getValue();
        return selfNonstandardValue.equals(this.jobType) || selfStandardValue.equals(this.jobType);
    }
    /**
     * 收费金额和国籍的字段
     */
    @Data
    @AllArgsConstructor
    public static class Charge {
        /**
         * 收费金额
         */
        private String charge;
        /**
         * 国籍
         */
        private String nationality;

        public Charge() {
        }
    }
}
