package com.gosingapore.common.util.procedure;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gosingapore.common.constants.CommonConstants;
import com.cloud.gs.hiring.common.enums.LibraryTypeEnum;
import com.gosingapore.common.enums.dict.Dict1DelFlagEnum;
import com.cloud.gs.hiring.common.enums.dict.Dict29DwCountryEnum;
import com.gosingapore.common.enums.procedure.ProcedureContentFlagEnum;
import com.cloud.gs.hiring.common.mapper.GsJobMapper;
import com.cloud.gs.hiring.common.mapper.employer.erp.GsErpDwLibraryChMapper;
import com.cloud.gs.hiring.common.mapper.employer.erp.GsErpDwLibraryYnMapper;
import com.cloud.gs.hiring.common.mapper.job.GsErpCompanyJobMapper;
import com.cloud.gs.hiring.common.mapper.procedure.GsProcedureContentFlagMapper;
import com.cloud.gs.hiring.common.mapper.procedure.GsResumeProcedureItemActionValueMapper;
import com.cloud.gs.hiring.common.mapper.procedure.GsResumeProcedureMapper;
import com.cloud.gs.hiring.common.mapper.resume.GsResumeMapper;
import com.cloud.gs.hiring.common.model.bo.ResumeProcedureItemActionValueBo;
import com.cloud.gs.hiring.common.model.entity.*;
import com.cloud.gs.hiring.common.model.entity.employer.erp.GsErpCompanyJob;
import com.cloud.gs.hiring.common.model.entity.employer.erp.GsErpDwLibraryCh;
import com.cloud.gs.hiring.common.model.entity.employer.erp.GsErpDwLibraryYn;
import com.cloud.gs.hiring.common.util.job.JobUtil;
import com.cloud.gs.hiring.common.util.popularize.PopularizeUtil;
import com.gosingapore.common.util.saleafter.TrainingAbroadUtil;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author ZhangJinyu
 * @since 2020-07-08
 */
@Component
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class ProcedureContentFlagUtil {
    final GsProcedureContentFlagMapper gsProcedureContentFlagMapper;
    final GsResumeProcedureMapper gsResumeProcedureMapper;
    final GsResumeMapper gsResumeMapper;
    final GsErpCompanyJobMapper gsErpCompanyJobMapper;
    final GsResumeProcedureItemActionValueMapper gsResumeProcedureItemActionValueMapper;
    final TrainingAbroadUtil trainingAbroadUtil;
    final GsErpDwLibraryYnMapper gsErpDwLibraryYnMapper;
    final GsErpDwLibraryChMapper gsErpDwLibraryChMapper;
    final JobUtil jobUtil;
    final GsJobMapper gsJobMapper;
    final PopularizeUtil popularizeUtil;

    /**
     * 手续办理事项已处理
     *
     * @param gsResumeProcedureItem 手续办理事项
     */
    public void procedureItemProcessed(GsResumeProcedureItem gsResumeProcedureItem) {
        Integer resumeProcedureId = gsResumeProcedureItem.getResumeProcedureId();
        if (Objects.isNull(resumeProcedureId)) {
            return;
        }
        GsResumeProcedure gsResumeProcedure = gsResumeProcedureMapper.selectById(resumeProcedureId);
        if (Objects.isNull(gsResumeProcedure)) {
            return;
        }
        Integer resumeId = gsResumeProcedure.getResumeId();
        if (Objects.isNull(resumeId)) {
            return;
        }
        GsResume gsResume = gsResumeMapper.selectById(resumeId);
        if (ObjectUtils.isEmpty(gsResume)) {
            return;
        }
        List<GsProcedureContentFlag> gsProcedureContentFlags = gsProcedureContentFlagMapper.selectList(new QueryWrapper<>());
        if (!CollectionUtils.isEmpty(gsProcedureContentFlags)) {
            for (GsProcedureContentFlag gsProcedureContentFlag : gsProcedureContentFlags) {
                String procedureContentFlag = gsProcedureContentFlag.getProcedureContentFlag();
                ProcedureContentFlagEnum procedureContentFlagEnum = ProcedureContentFlagEnum.get(procedureContentFlag);
                if (!Objects.isNull(procedureContentFlagEnum)) {
                    switch (procedureContentFlagEnum) {
                        case IPA:
                            if (gsProcedureContentFlag.getProcedureContentId().equals(gsResumeProcedureItem.getProcedureItemId())) {
                                // 电文投递列表手续办理 电文操作IPA 如果是中国或者越南电文操作 将发布职位的雇主添加到已批库
                                GsErpCompanyJob gsErpCompanyJob = gsErpCompanyJobMapper.selectOne(new LambdaQueryWrapper<GsErpCompanyJob>()
                                        .eq(GsErpCompanyJob::getJobId, gsResumeProcedure.getJobId()));
                                GsJob gsJob = gsJobMapper.selectById(gsResumeProcedure.getJobId());
                                if (!ObjectUtils.isEmpty(gsErpCompanyJob)) {
                                    Integer archiveId = gsErpCompanyJob.getEmployerArchiveId();
                                    Dict29DwCountryEnum dict29DwCountryEnum = Dict29DwCountryEnum.instanceOf(gsErpCompanyJob.getUserCountryValue());
                                    if (!ObjectUtils.isEmpty(dict29DwCountryEnum)) {
                                        switch (dict29DwCountryEnum) {
                                            case VIETNAM:
                                                jobUtil.checkLibraryCapacityYn(archiveId, gsJob.getTypeValue(), LibraryTypeEnum.FOREVER);
                                                GsErpDwLibraryYn gsErpDwLibraryYn = gsErpDwLibraryYnMapper.selectOne(new LambdaQueryWrapper<GsErpDwLibraryYn>()
                                                        .eq(GsErpDwLibraryYn::getArchiveId, archiveId)
                                                        .eq(GsErpDwLibraryYn::getLibType, LibraryTypeEnum.SINGLE_OUT.getValue())
                                                        .lt(GsErpDwLibraryYn::getRemoveTime, CommonConstants.INSTANT_2000));
                                                if (!ObjectUtils.isEmpty(gsErpDwLibraryYn)) {
                                                    gsErpDwLibraryYnMapper.updateById(new GsErpDwLibraryYn().setLibType(LibraryTypeEnum.FOREVER.getValue()).setId(gsErpDwLibraryYn.getId()));
                                                }
                                                break;
                                            case CHINA:
                                                jobUtil.checkLibraryCapacityCh(archiveId, gsJob.getTypeValue(), LibraryTypeEnum.FOREVER);
                                                GsErpDwLibraryCh gsErpDwLibraryCh = gsErpDwLibraryChMapper.selectOne(new LambdaQueryWrapper<GsErpDwLibraryCh>()
                                                        .eq(GsErpDwLibraryCh::getArchiveId, archiveId)
                                                        .eq(GsErpDwLibraryCh::getLibType, LibraryTypeEnum.SINGLE_OUT.getValue())
                                                        .lt(GsErpDwLibraryCh::getRemoveTime, CommonConstants.INSTANT_2000));
                                                if (!ObjectUtils.isEmpty(gsErpDwLibraryCh)) {
                                                    gsErpDwLibraryChMapper.updateById(new GsErpDwLibraryCh().setLibType(LibraryTypeEnum.FOREVER.getValue()).setId(gsErpDwLibraryCh.getId()));
                                                }
                                                break;
                                            default:
                                                break;
                                        }
                                    }
                                }
                                trainingAbroadUtil.saveResumeIdToTrainingAbroad(gsResumeProcedure.getResumeId(),
                                        gsResumeProcedureItem, procedureContentFlagEnum);
                            }
                            break;
                        case PASSPORT_NO:
                        case AIR_TICKETS:
                        case START_WORKING:
                        case IN_SINGAPORE:
                        case IPA_TYPE:
                            trainingAbroadUtil.saveResumeIdToTrainingAbroad(gsResumeProcedure.getResumeId(),
                                    gsResumeProcedureItem, procedureContentFlagEnum);
                            break;
                        case ISSUE:
                            if (gsProcedureContentFlag.getProcedureContentId().equals(gsResumeProcedureItem.getProcedureItemId())) {
                                Integer customerId = gsResume.getCustomerId();
                                // 校验工人是否是地推受邀人,设置积分兑换时间  白海波
                                //盛雪 入职状态改为在点击已完成节点确认
                                //popularizeUtil.popularizeExchangeIntegralOfCustomer(customerId);
                            }
                            break;
                        default:
                            break;
                    }
                }
            }
        }
    }

    /**
     * 根据简历id和手续办理内容标记获取手续办理对应的值
     *
     * @param chineseLanguage          是否是中文语言,可为null
     * @param resumeId                 简历id
     * @param procedureContentFlagEnum 手续办理内容标记
     * @return 简历手续办理对应的值
     */
    public List<ResumeProcedureItemActionValueBo> getResumeProcedureItemActionValues(Boolean chineseLanguage, Integer resumeId, ProcedureContentFlagEnum procedureContentFlagEnum) {
        GsResumeProcedure gsResumeProcedure = gsResumeProcedureMapper.selectByResumeId(resumeId);
        if (Objects.isNull(gsResumeProcedure)) {
            return Collections.emptyList();
        }
        List<GsProcedureContentFlag> gsProcedureContentFlags = gsProcedureContentFlagMapper.selectList(new LambdaQueryWrapper<GsProcedureContentFlag>()
                .eq(GsProcedureContentFlag::getProcedureContentFlag, procedureContentFlagEnum.getContentFlag())
                .eq(GsProcedureContentFlag::getDelFlag, Dict1DelFlagEnum.NOT_DELETED.getValue()));
        if (CollectionUtils.isEmpty(gsProcedureContentFlags)) {
            return Collections.emptyList();
        }
        List<ResumeProcedureItemActionValueBo> resumeProcedureItemActionValueBos = new ArrayList<>();
        for (GsProcedureContentFlag gsProcedureContentFlag : gsProcedureContentFlags) {
            Integer procedureContentType = gsProcedureContentFlag.getProcedureContentType();
            Integer procedureContentId = gsProcedureContentFlag.getProcedureContentId();
            switch (procedureContentType) {
                /*事项id*/
                case 1:
                    resumeProcedureItemActionValueBos.addAll(gsResumeProcedureItemActionValueMapper.selectResumeProcedureItemActionValueBoByResumeIdAndProcedureItemId(chineseLanguage, resumeId, procedureContentId));
                    break;
                /*事项下的行为id*/
                case 2:
                    resumeProcedureItemActionValueBos.addAll(gsResumeProcedureItemActionValueMapper.selectResumeProcedureItemActionValueBoByResumeIdAndProcedureItemActionId(chineseLanguage, resumeId, procedureContentId));
                    break;
                default:
                    break;
            }
        }
        for (ResumeProcedureItemActionValueBo resumeProcedureItemActionValueBo : resumeProcedureItemActionValueBos) {
            resumeProcedureItemActionValueBo.setResumeId(resumeId);
            resumeProcedureItemActionValueBo.setProcedureContentFlag(procedureContentFlagEnum.getContentFlag());
        }
        return resumeProcedureItemActionValueBos;
    }

    /**
     * 根据简历id和手续办理内容标记获取手续办理对应的值
     *
     * @param chineseLanguage           是否是中文语言,可为null
     * @param resumeIds                 简历id
     * @param procedureContentFlagEnums 手续办理内容标记
     * @return 简历手续办理对应的值
     */
    public List<ResumeProcedureItemActionValueBo> getResumeProcedureItemActionValues(Boolean chineseLanguage, List<Integer> resumeIds, List<ProcedureContentFlagEnum> procedureContentFlagEnums) {
        if (CollectionUtils.isEmpty(resumeIds)) {
            return Collections.emptyList();
        }
        if (CollectionUtils.isEmpty(procedureContentFlagEnums)) {
            return Collections.emptyList();
        }
        List<GsResumeProcedure> gsResumeProcedures = gsResumeProcedureMapper.selectList(new LambdaQueryWrapper<GsResumeProcedure>().in(GsResumeProcedure::getResumeId, resumeIds));
        if (CollectionUtils.isEmpty(gsResumeProcedures)) {
            return Collections.emptyList();
        }
        List<String> contentFlags = procedureContentFlagEnums.stream().map(ProcedureContentFlagEnum::getContentFlag).distinct().collect(Collectors.toList());
        List<GsProcedureContentFlag> gsProcedureContentFlags = gsProcedureContentFlagMapper.selectList(new LambdaQueryWrapper<GsProcedureContentFlag>()
                .in(GsProcedureContentFlag::getProcedureContentFlag, contentFlags)
                .eq(GsProcedureContentFlag::getDelFlag, Dict1DelFlagEnum.NOT_DELETED.getValue()));
        if (CollectionUtils.isEmpty(gsProcedureContentFlags)) {
            return Collections.emptyList();
        }
        Map<Integer, List<GsProcedureContentFlag>> gsProcedureContentFlagsForContentFlagMap = gsProcedureContentFlags.stream().collect(Collectors.groupingBy(GsProcedureContentFlag::getProcedureContentType));
        List<ResumeProcedureItemActionValueBo> resumeProcedureItemActionValueBos = new ArrayList<>();
        for (Integer contentFlagType : gsProcedureContentFlagsForContentFlagMap.keySet()) {
            List<GsProcedureContentFlag> gsProcedureContentFlagsTemp = gsProcedureContentFlagsForContentFlagMap.get(contentFlagType);
            List<Integer> contentFlagIds = gsProcedureContentFlagsTemp.stream().map(GsProcedureContentFlag::getProcedureContentId).distinct().collect(Collectors.toList());
            Map<Integer, GsProcedureContentFlag> gsProcedureContentFlagsTempForContentIdMap = gsProcedureContentFlagsTemp.stream().collect(Collectors.toMap(GsProcedureContentFlag::getProcedureContentId, value -> value));
            switch (contentFlagType) {
                /*事项id*/
                case 1:
                    List<ResumeProcedureItemActionValueBo> resumeProcedureItemActionValueBos1 = gsResumeProcedureItemActionValueMapper.selectResumeProcedureItemActionValueBoByResumeIdAndProcedureItemIds(chineseLanguage, resumeIds, contentFlagIds);
                    for (ResumeProcedureItemActionValueBo resumeProcedureItemActionValueBo : resumeProcedureItemActionValueBos1) {
                        Integer procedureContentId = resumeProcedureItemActionValueBo.getProcedureContentId();
                        GsProcedureContentFlag gsProcedureContentFlag = gsProcedureContentFlagsTempForContentIdMap.get(procedureContentId);
                        if (!Objects.isNull(gsProcedureContentFlag)) {
                            resumeProcedureItemActionValueBo.setProcedureContentFlag(gsProcedureContentFlag.getProcedureContentFlag());
                        }
                    }
                    resumeProcedureItemActionValueBos.addAll(resumeProcedureItemActionValueBos1);
                    break;
                /*事项下的行为id*/
                case 2:
                    List<ResumeProcedureItemActionValueBo> resumeProcedureItemActionValueBos2 = gsResumeProcedureItemActionValueMapper.selectResumeProcedureItemActionValueBoByResumeIdAndProcedureItemActionIds(chineseLanguage, resumeIds, contentFlagIds);
                    for (ResumeProcedureItemActionValueBo resumeProcedureItemActionValueBo : resumeProcedureItemActionValueBos2) {
                        Integer procedureContentId = resumeProcedureItemActionValueBo.getProcedureContentId();
                        GsProcedureContentFlag gsProcedureContentFlag = gsProcedureContentFlagsTempForContentIdMap.get(procedureContentId);
                        if (!Objects.isNull(gsProcedureContentFlag)) {
                            resumeProcedureItemActionValueBo.setProcedureContentFlag(gsProcedureContentFlag.getProcedureContentFlag());
                        }
                    }
                    resumeProcedureItemActionValueBos.addAll(resumeProcedureItemActionValueBos2);
                    break;
                default:
                    break;
            }
        }
        return resumeProcedureItemActionValueBos;
    }

}
