package com.gosingapore.common.util.procedure;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cloud.gs.hiring.base.util.ResponseCode;
import com.gosingapore.common.constants.FileTypeConstants;
import com.cloud.gs.hiring.common.enums.LibraryTypeEnum;
import com.gosingapore.common.enums.dict.Dict111PartiesEnum;
import com.cloud.gs.hiring.common.enums.dict.Dict22ResumeStatusEnum;
import com.cloud.gs.hiring.common.enums.procedure.*;
import com.gosingapore.common.enums.procedure.ProcedureItemPermitEnum;
import com.gosingapore.common.enums.procedure.ProcedureValueTypeEnum;
import com.gosingapore.common.enums.procedure.ResumeProcedureItemProcessingStatusEnum;
import com.gosingapore.common.exception.CustomizeException;
import com.cloud.gs.hiring.common.mapper.GsCpUserMapper;
import com.cloud.gs.hiring.common.mapper.GsSysDictMapper;
import com.cloud.gs.hiring.common.mapper.employer.cp.GsCpDwPrivateEmployerMapper;
import com.cloud.gs.hiring.common.mapper.employer.erp.GsErpDwLibraryMlMapper;
import com.cloud.gs.hiring.common.mapper.procedure.*;
import com.cloud.gs.hiring.common.mapper.resume.GsResumeStatusMapper;
import com.cloud.gs.hiring.common.model.bean.procedure.ProcedureItemActionValueWrapper;
import com.cloud.gs.hiring.common.model.bean.procedure.ProcedureItemActionWrapper;
import com.cloud.gs.hiring.common.model.dto.procedure.*;
import com.cloud.gs.hiring.common.model.entity.*;
import com.cloud.gs.hiring.common.model.entity.employer.erp.GsErpDwLibraryMl;
import com.cloud.gs.hiring.common.model.query.procedure.ResumeProcedureItemSaveQuery;
import com.cloud.gs.hiring.common.model.vo.GsSysDictVo;
import com.gosingapore.common.model.entity.GsCpUser;
import com.gosingapore.common.util.FileSuffixUtil;
import com.gosingapore.common.util.StreamUtil;
import com.cloud.gs.hiring.common.util.SwitchUtil;
import com.gosingapore.common.util.UserUtil;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.BooleanUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.time.Instant;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

import static com.gosingapore.common.constants.CommonConstants.INSTANT_2000;

/**
 * 简历的手续办理保存工具类
 *
 * @author ZhangJinyu
 * @since 2020-05-14
 */
@Component
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
public class ResumeProcedureSaveUtil {
    final GsResumeProcedureMapper gsResumeProcedureMapper;
    final GsResumeProcedureItemMapper gsResumeProcedureItemMapper;
    final GsProcedureItemActionMapper gsProcedureItemActionMapper;
    final GsResumeProcedureItemActionMapper gsResumeProcedureItemActionMapper;
    final GsProcedureItemActionGroupMapMapper gsProcedureItemActionGroupMapMapper;
    final GsProcedureItemTypePermitMapper gsProcedureItemTypePermitMapper;
    final GsProcedureItemActionValueMapper gsProcedureItemActionValueMapper;
    final GsResumeProcedureItemActionValueMapper gsResumeProcedureItemActionValueMapper;
    final GsResumeProcedureItemRevealMapper gsResumeProcedureItemRevealMapper;
    final GsProcedureItemRevealMapper gsProcedureItemRevealMapper;
    final GsSysDictMapper gsSysDictMapper;
    final ProcedureMessageUtil procedureMessageUtil;
    final GsResumeStatusMapper resumeStatusMapper;
    final ResumeProcedureAppPushMsgUtil resumeProcedureAppPushMsgUtil;
    final ProcedureContentFlagUtil procedureContentFlagUtil;
    final GsResumeProcedureTypeMapper gsResumeProcedureTypeMapper;
    final ProcedureRoleHandler procedureRoleHandler;
    final ProcedureActionExcludeUtil procedureActionExcludeUtil;
    final GsCpDwPrivateEmployerMapper gsCpDwPrivateEmployerMapper;
    final GsCpUserMapper gsCpUserMapper;
    final SwitchUtil switchUtil;
    final GsErpDwLibraryMlMapper gsErpDwLibraryMlMapper;

    /**
     * 手续办理项存储
     *
     * @param resumeProcedureItemSaveQuery 手续办理项存储参数
     */
    @Transactional(rollbackFor = Exception.class)
    public void resumeProcedureItemSave(ResumeProcedureItemSaveQuery resumeProcedureItemSaveQuery) {
        Integer procedureUserRole = procedureRoleHandler.getCurrentUserProcedureUserRole();
        boolean draft = resumeProcedureItemSaveQuery.isDraft();
        List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> needSaveProcedureItemActions = resumeProcedureItemSaveQuery.getProcedureItemActions();
        if (CollectionUtils.isEmpty(needSaveProcedureItemActions)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "请填写办理事项内容", "Please fill in the procedure item content");
        }
        Integer resumeId = resumeProcedureItemSaveQuery.getResumeId();
        GsResumeProcedure gsResumeProcedure = gsResumeProcedureMapper.selectByResumeId(resumeId);
        if (Objects.isNull(gsResumeProcedure)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "未到手续办理流程", "The procedure hasn't arrived yet");
        }
        List<GsResumeStatus> gsResumeStatuses = resumeStatusMapper.selectByResumeId(resumeId);
        Optional<GsResumeStatus> optionalAny = gsResumeStatuses.stream().filter(gsResumeStatus -> {
            Integer status = gsResumeStatus.getStatus();
            return Dict22ResumeStatusEnum.procedureCanEdit(status);
        }).findAny();
        if (!optionalAny.isPresent()) {
            /*简历存在不允许办理手续的状态*/
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "简历状态不允许进行手续办理", "Resume status does not allow for procedure");
        }
        Integer resumeProcedureId = gsResumeProcedure.getResumeProcedureId();
        Integer resumeProcedureItemId = resumeProcedureItemSaveQuery.getResumeProcedureItemId();
        GsResumeProcedureItem gsResumeProcedureItem = gsResumeProcedureItemMapper.selectByResumeProcedureIdAndId(resumeProcedureId, resumeProcedureItemId);
        if (Objects.isNull(gsResumeProcedureItem)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "此简历没有对应的手续办理事项", "There is no corresponding procedure for this resume");
        }
        Integer procedureItemId = gsResumeProcedureItem.getProcedureItemId();
        Integer userCode = Objects.requireNonNull(UserUtil.getParty()).getCode();
        // 判断职位类型,cp非标单不做校验
        if(4 != gsResumeProcedure.getJobType()){
            // 不是草稿,校验CP电文上传IPA时7为手续办理的IPA节点,已批库的库容 2021-02-02 add
            if (!draft && procedureItemId.equals(7)) {
                if (Dict111PartiesEnum.AGENCY.getCode().equals(userCode)) {
                    capacityCheck(gsResumeProcedure.getJobId());
                } else if (Dict111PartiesEnum.SELF.getCode().equals(userCode)) {
                    // 自营判断库容
                    Integer approvedTotal = switchUtil.getSwitchSetting().getMlDwApprovedStoreLimit();
                    Integer approvedUser = gsErpDwLibraryMlMapper.selectCount(
                            Wrappers.lambdaQuery(new GsErpDwLibraryMl())
                                    .eq(GsErpDwLibraryMl::getUserId,UserUtil.getUserId())
                                    .eq(GsErpDwLibraryMl::getLibType, LibraryTypeEnum.FOREVER.getValue())
                                    .lt(GsErpDwLibraryMl::getRemoveTime,INSTANT_2000));
                    if (approvedUser > approvedTotal){
                        throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "您的已批库已满,无法上传IPA", "Your approved library is full and you cannot upload IPA");
                    }
                }
            }
        }
        List<Integer> procedureTypes = gsResumeProcedureTypeMapper.selectProcedureTypes(resumeProcedureId);
        List<UserProcedureItemPermitDTO> userProcedureItemPermitDTOList = gsProcedureItemTypePermitMapper.selectByProcedureTypeAndProcedureUserRole(procedureTypes, procedureUserRole);
        if (!CollectionUtils.isEmpty(userProcedureItemPermitDTOList)) {
            Optional<UserProcedureItemPermitDTO> first = userProcedureItemPermitDTOList.stream().filter(userProcedureItemPermitDTO -> userProcedureItemPermitDTO.getProcedureItemId().equals(procedureItemId) && ProcedureItemPermitEnum.canEdit(userProcedureItemPermitDTO.getPermitCodes())).findFirst();
            if (!first.isPresent()) {
                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "您没有操作权限", "You don't have permission to operate");
            }
        }
        if (BooleanUtils.isTrue(gsResumeProcedure.getCompleted())) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "手续办理已完成,不能再处理事项", "The procedure has been completed and the item can no longer be processed");
        }
        if (ResumeProcedureItemProcessingStatusEnum.get(gsResumeProcedureItem.getProcessingStatus()).isProcessed()) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "此事项已确认办理,如需修改,请联系您的业务负责人", "This matter has been confirmed, if you need to modify, please contact your business person in charge");
        }
        List<GsProcedureItemActionWithTypeDTO> gsProcedureItemActionList = gsProcedureItemActionMapper.selectGsProcedureItemActionWithTypeDTOByProcedureItemIdAndProcedureType(procedureItemId, procedureTypes);
        if (CollectionUtils.isEmpty(gsProcedureItemActionList)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "请联系系统管理员配置手续办理内容", "Please contact the system administrator for configuration procedures");
        }
        List<GsProcedureItemActionGroupDTO> gsProcedureItemActionGroupDTOList = procedureItemActionToGsProcedureItemActionGroupDTO(gsProcedureItemActionList);

        List<ProcedureItemActionExclude> procedureItemActionExcludes = procedureActionExcludeUtil.getProcedureItemActionExclude(procedureItemId, procedureTypes);

        processNeedSaveProcedureItemActions(gsProcedureItemActionGroupDTOList, needSaveProcedureItemActions, procedureItemActionExcludes);
        saveResumeProcedure(draft, resumeId, UserUtil.getUserId(), Objects.requireNonNull(UserUtil.getParty()).getCode(), procedureUserRole, procedureTypes, gsResumeProcedureItem, gsProcedureItemActionGroupDTOList, needSaveProcedureItemActions);
        if (!draft) {
            procedureContentFlagUtil.procedureItemProcessed(gsResumeProcedureItem);
            procedureMessageUtil.pushItemNodeMessage(resumeId, procedureTypes, gsResumeProcedureItem);
        }
    }

    /**
     * 上传ipa校验已批库的库容
     */
    private void capacityCheck(Integer jobId){
        Integer userId = UserUtil.getUserId();
        GsCpUser cpUser = gsCpUserMapper.selectById(userId);
        if(cpUser.getApprovedStoreLimit() != -1){
            // 设置了库容
            // 已批库中的雇主不校验库容
            GsCpDwPrivateEmployer privateEmployer = gsCpDwPrivateEmployerMapper.getEmployerLibType(jobId,userId);
            if(Objects.nonNull(privateEmployer) && 3 == privateEmployer.getLibType()){
                return;
            }
            // 检验已批库的库容是否已满
            Integer approvedStoreCount =  gsCpDwPrivateEmployerMapper.getLibraryCountByLibType(cpUser.getUserId(),3);
            if(approvedStoreCount >= cpUser.getApprovedStoreLimit()){
                //已批库容量大于等于规定容量,不可上传IPA
                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "您的已批库已满,暂不可上传IPA", "Your approved library is full, you cannot upload IPA temporarily");
            }
        }
    }


    private void saveResumeProcedure(boolean draft, Integer resumeId, Integer operateUserId, Integer partyId, Integer procedureUserRole, List<Integer> procedureTypes, GsResumeProcedureItem
            resumeProcedureItem, List<GsProcedureItemActionGroupDTO> gsProcedureItemActionGroupDTOList, List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> needSaveProcedureItemActions) {
        Map<Integer, List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery>> needSaveProcedureItemActionsForActionIdMap = needSaveProcedureItemActions.stream().collect(Collectors.groupingBy(ResumeProcedureItemSaveQuery.ProcedureItemActionQuery::getProcedureItemActionId));
        List<ProcedureItemActionWrapper> procedureItemActionWrappers = new ArrayList<>();
        Map<Integer, List<ProcedureItemActionValueDTO>> procedureItemActionValueDtoListForActionIdMap;
        if (CollectionUtils.isEmpty(gsProcedureItemActionGroupDTOList)) {
            procedureItemActionValueDtoListForActionIdMap = Collections.emptyMap();
        } else {
            Set<Integer> procedureItemActionIds = new HashSet<>();
            for (GsProcedureItemActionGroupDTO gsProcedureItemActionGroupDTO : gsProcedureItemActionGroupDTOList) {
                Boolean grouped = gsProcedureItemActionGroupDTO.getGrouped();
                if (BooleanUtils.isTrue(grouped)) {
                    List<GsProcedureItemActionWithTypeDTO> groupChildList = gsProcedureItemActionGroupDTO.getGroupChildList();
                    for (GsProcedureItemAction gsProcedureItemAction : groupChildList) {
                        procedureItemActionIds.add(gsProcedureItemAction.getProcedureItemActionId());
                    }
                } else {
                    procedureItemActionIds.add(gsProcedureItemActionGroupDTO.getProcedureItemActionId());
                }
            }
            List<ProcedureItemActionValueDTO> procedureItemActionValueDTOList = gsProcedureItemActionValueMapper.selectByProcedureItemActionIds(null, new ArrayList<>(procedureItemActionIds));
            procedureItemActionValueDtoListForActionIdMap = procedureItemActionValueDTOList.stream().collect(Collectors.groupingBy(ProcedureItemActionValueDTO::getProcedureItemActionId));
        }
        for (GsProcedureItemActionGroupDTO gsProcedureItemActionGroupDTO : gsProcedureItemActionGroupDTOList) {
            Integer procedureItemActionId = gsProcedureItemActionGroupDTO.getProcedureItemActionId();
            Boolean grouped = gsProcedureItemActionGroupDTO.getGrouped();
            List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> procedureItemActionQueries = needSaveProcedureItemActionsForActionIdMap.get(procedureItemActionId);
            if (grouped) {
                procedureItemActionWrappers.addAll(processGroupActionValue(gsProcedureItemActionGroupDTO, procedureItemActionValueDtoListForActionIdMap, procedureItemActionQueries));
            } else {
                procedureItemActionWrappers.add(processNormalActionValue(gsProcedureItemActionGroupDTO, procedureItemActionValueDtoListForActionIdMap, procedureItemActionQueries));
            }
        }
        /*处理手续办理存储*/
        processProcedureItemSave(draft, operateUserId, partyId, resumeProcedureItem, procedureItemActionWrappers);
        if (!draft) {
            /*处理自动呈现APP*/
            processAutoRevealApp(resumeId, procedureUserRole, procedureTypes, resumeProcedureItem);
        }
    }

    private void processProcedureItemSave(boolean draft, Integer operateUserId, Integer partyId, GsResumeProcedureItem
            resumeProcedureItem, List<ProcedureItemActionWrapper> procedureItemActionWrappers) {
        gsResumeProcedureItemActionMapper.delete(new LambdaUpdateWrapper<GsResumeProcedureItemAction>().eq(GsResumeProcedureItemAction::getResumeProcedureItemId, resumeProcedureItem.getResumeProcedureItemId()));
        for (ProcedureItemActionWrapper procedureItemActionWrapper : procedureItemActionWrappers) {
            GsResumeProcedureItemAction gsResumeProcedureItemAction = new GsResumeProcedureItemAction();
            gsResumeProcedureItemAction.setResumeProcedureId(resumeProcedureItem.getResumeProcedureId());
            gsResumeProcedureItemAction.setResumeProcedureItemId(resumeProcedureItem.getResumeProcedureItemId());
            gsResumeProcedureItemAction.setProcedureItemActionId(procedureItemActionWrapper.getProcedureItemActionId());
            gsResumeProcedureItemAction.setOrders(procedureItemActionWrapper.getOrders());
            gsResumeProcedureItemAction.setValueType(procedureItemActionWrapper.getValueType());
            gsResumeProcedureItemAction.setValueTypeCode(procedureItemActionWrapper.getValueTypeCode());
            gsResumeProcedureItemAction.setRequired(procedureItemActionWrapper.getRequired());
            gsResumeProcedureItemAction.setGrouped(procedureItemActionWrapper.getGrouped());
            gsResumeProcedureItemActionMapper.insert(gsResumeProcedureItemAction);
            Integer resumeProcedureItemActionId = gsResumeProcedureItemAction.getResumeProcedureItemActionId();
            Boolean grouped = procedureItemActionWrapper.getGrouped();
            if (grouped) {
                List<ProcedureItemActionWrapper> groupChild = procedureItemActionWrapper.getGroupChild();
                saveGroupChildAction(resumeProcedureItemActionId, resumeProcedureItem, groupChild);
            } else {
                saveResumeProcedureItemActionValue(resumeProcedureItemActionId, resumeProcedureItem.getResumeProcedureId(), procedureItemActionWrapper.getProcedureItemActionValueWrappers());
            }
        }
        gsResumeProcedureMapper.updateUpdateTimeById(resumeProcedureItem.getResumeProcedureId());
        /*更新简历手续办理事项处理状态*/
        updateResumeProcedureItemProcessingStatus(draft, operateUserId, partyId, resumeProcedureItem);
    }

    private void saveGroupChildAction(Integer resumeProcedureItemActionId, GsResumeProcedureItem
            gsResumeProcedureItem, List<ProcedureItemActionWrapper> procedureItemActionWrappers) {
        for (ProcedureItemActionWrapper procedureItemActionWrapper : procedureItemActionWrappers) {
            GsResumeProcedureItemAction gsResumeProcedureItemActionChild = new GsResumeProcedureItemAction();
            gsResumeProcedureItemActionChild.setParentId(resumeProcedureItemActionId);
            gsResumeProcedureItemActionChild.setResumeProcedureId(gsResumeProcedureItem.getResumeProcedureId());
            gsResumeProcedureItemActionChild.setResumeProcedureItemId(gsResumeProcedureItem.getResumeProcedureItemId());
            gsResumeProcedureItemActionChild.setProcedureItemActionId(procedureItemActionWrapper.getProcedureItemActionId());
            gsResumeProcedureItemActionChild.setValueType(procedureItemActionWrapper.getValueType());
            gsResumeProcedureItemActionChild.setValueTypeCode(procedureItemActionWrapper.getValueTypeCode());
            gsResumeProcedureItemActionChild.setOrders(procedureItemActionWrapper.getOrders());
            gsResumeProcedureItemActionMapper.insert(gsResumeProcedureItemActionChild);
            List<ProcedureItemActionValueWrapper> procedureItemActionValueWrappers = procedureItemActionWrapper.getProcedureItemActionValueWrappers();
            if (!CollectionUtils.isEmpty(procedureItemActionValueWrappers)) {
                saveResumeProcedureItemActionValue(gsResumeProcedureItemActionChild.getResumeProcedureItemActionId(), gsResumeProcedureItem.getResumeProcedureId(), procedureItemActionValueWrappers);
            }
        }
    }

    private void processAutoRevealApp(Integer resumeId, Integer procedureUserRole, List<Integer> procedureTypes, GsResumeProcedureItem resumeProcedureItem) {
        boolean workerRevealPush = false;
        boolean employerRevealPush = false;
        Integer resumeProcedureItemId = resumeProcedureItem.getResumeProcedureItemId();
        Integer procedureItemId = resumeProcedureItem.getProcedureItemId();
        List<GsProcedureItemReveal> gsProcedureItemReveals = gsProcedureItemRevealMapper.selectByProcedureUserRoleAndProcedureItemIdAndProcedureType(procedureUserRole, procedureItemId, procedureTypes);
        if (!CollectionUtils.isEmpty(gsProcedureItemReveals)) {
            for (GsProcedureItemReveal gsProcedureItemReveal : gsProcedureItemReveals) {
                ProcedureItemRevealTypeEnum procedureItemRevealTypeEnum = ProcedureItemRevealTypeEnum.get(gsProcedureItemReveal.getRevealType());
                if (ProcedureItemRevealTypeEnum.REVEAL.equals(procedureItemRevealTypeEnum)) {
                    GsResumeProcedureItemReveal gsResumeProcedureItemReveal = gsResumeProcedureItemRevealMapper.selectByResumeProcedureItemId(resumeProcedureItemId);
                    if (!Objects.isNull(gsResumeProcedureItemReveal)) {
                        if (procedureUserRole.equals(0)) {
                            Integer workerCanReveal = gsResumeProcedureItemReveal.getWorkerCanReveal();
                            Boolean workerReveal = gsResumeProcedureItemReveal.getWorkerReveal();
                            if (workerCanReveal == 1 && BooleanUtils.isFalse(workerReveal)) {
                                gsResumeProcedureItemReveal.setWorkerReveal(Boolean.TRUE);
                                workerRevealPush = gsResumeProcedureItemReveal.getWorkerCanPush();
                                gsResumeProcedureItemRevealMapper.updateById(gsResumeProcedureItemReveal);
                            }
                        }
                        if (procedureUserRole.equals(1)) {
                            Integer employerCanReveal = gsResumeProcedureItemReveal.getEmployerCanReveal();
                            Boolean employerReveal = gsResumeProcedureItemReveal.getEmployerReveal();
                            if (employerCanReveal == 1 && BooleanUtils.isFalse(employerReveal)) {
                                gsResumeProcedureItemReveal.setEmployerReveal(Boolean.TRUE);
                                employerRevealPush = gsResumeProcedureItemReveal.getEmployerCanPush();
                                gsResumeProcedureItemRevealMapper.updateById(gsResumeProcedureItemReveal);
                            }
                        }
                    }
                }
            }
        }
        if (workerRevealPush) {
            resumeProcedureAppPushMsgUtil.workerPushProcedureItemReveal(resumeId, resumeProcedureItem);
        }
        if (employerRevealPush) {
            resumeProcedureAppPushMsgUtil.employerPushProcedureItemReveal(resumeId, resumeProcedureItem);
        }
    }

    private void updateResumeProcedureItemProcessingStatus(boolean draft, Integer operateUserId, Integer partyId, GsResumeProcedureItem resumeProcedureItem) {
        resumeProcedureItem.setOperateUserId(operateUserId);
        resumeProcedureItem.setPartyId(partyId);
        resumeProcedureItem.setProcessingStatus(draft ? ResumeProcedureItemProcessingStatusEnum.DEFAULT.getValue() : ResumeProcedureItemProcessingStatusEnum.PROCESSED.getValue());
        resumeProcedureItem.setCompleteTime(Instant.now());
        gsResumeProcedureItemMapper.updateById(resumeProcedureItem);
    }

    private void saveResumeProcedureItemActionValue(Integer resumeProcedureItemActionId, Integer
            resumeProcedureId, List<ProcedureItemActionValueWrapper> procedureItemActionValueWrappers) {
        gsResumeProcedureItemActionValueMapper.delete(new LambdaUpdateWrapper<GsResumeProcedureItemActionValue>().eq(GsResumeProcedureItemActionValue::getResumeProcedureItemActionId, resumeProcedureItemActionId));
        for (ProcedureItemActionValueWrapper procedureItemActionValueWrapper : procedureItemActionValueWrappers) {
            GsResumeProcedureItemActionValue gsResumeProcedureItemActionValue = new GsResumeProcedureItemActionValue();
            gsResumeProcedureItemActionValue.setResumeProcedureId(resumeProcedureId);
            gsResumeProcedureItemActionValue.setResumeProcedureItemActionId(resumeProcedureItemActionId);
            gsResumeProcedureItemActionValue.setResultId(procedureItemActionValueWrapper.getId());
            gsResumeProcedureItemActionValue.setResultChValue(procedureItemActionValueWrapper.getChName());
            gsResumeProcedureItemActionValue.setResultEnValue(procedureItemActionValueWrapper.getEnName());
            gsResumeProcedureItemActionValueMapper.insert(gsResumeProcedureItemActionValue);
        }
    }

    /**
     * 处理用户输入的办理事项行为数据,将不满足要求的剔除
     *
     * @param gsProcedureItemActionGroupDTOList 手续办理事项行为的模版数据
     * @param needSaveProcedureItemActions      用户输入的办理事项行为数据
     * @param procedureItemActionExcludes       排除的行为关系数据
     */
    private void processNeedSaveProcedureItemActions
    (List<GsProcedureItemActionGroupDTO> gsProcedureItemActionGroupDTOList, List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> needSaveProcedureItemActions, List<ProcedureItemActionExclude> procedureItemActionExcludes) {
        Map<Integer, List<ProcedureItemActionExclude>> procedureItemActionExcludesForActionIdMap = procedureItemActionExcludes.stream().collect(Collectors.groupingBy(ProcedureItemActionExclude::getProcedureItemActionId));
        Map<Integer, GsProcedureItemActionGroupDTO> gsProcedureItemActionGroupDtoListForProcedureItemActionIdMap = gsProcedureItemActionGroupDTOList.stream().collect(Collectors.toMap(GsProcedureItemActionGroupDTO::getProcedureItemActionId, value -> value));
        Set<Integer> removeProcedureItemActionIdSet = new HashSet<>();
        /*这里根据选项值,进行action的过滤,去除不需要存储的action值*/
        for (ResumeProcedureItemSaveQuery.ProcedureItemActionQuery needSaveProcedureItemAction : needSaveProcedureItemActions) {
            Integer procedureItemActionId = needSaveProcedureItemAction.getProcedureItemActionId();
            if (procedureItemActionExcludesForActionIdMap.containsKey(procedureItemActionId)) {
                List<ProcedureItemActionExclude> procedureItemActionExcludes1 = procedureItemActionExcludesForActionIdMap.get(procedureItemActionId);
                if (Objects.nonNull(procedureItemActionExcludes1)) {
                    Map<String, List<ProcedureItemActionExclude>> collect = procedureItemActionExcludes1.stream().collect(Collectors.groupingBy(ProcedureItemActionExclude::getProcedureItemActionValueId));
                    Set<String> strings = collect.keySet();
                    GsProcedureItemActionGroupDTO gsProcedureItemActionGroupDTO = gsProcedureItemActionGroupDtoListForProcedureItemActionIdMap.get(procedureItemActionId);
                    /*现在没有分组需求,如果需要再实现*/
                    if (!gsProcedureItemActionGroupDTO.getGrouped()) {
                        List<String> procedureItemActionValues = needSaveProcedureItemAction.getProcedureItemActionValues();
                        procedureItemActionValues.stream().filter(strings::contains).forEach(s -> {
                            List<ProcedureItemActionExclude> procedureItemActionExcludes2 = collect.get(s);
                            if (Objects.nonNull(procedureItemActionExcludes2)) {
                                for (ProcedureItemActionExclude procedureItemActionExclude : procedureItemActionExcludes2) {
                                    removeProcedureItemActionIdSet.addAll(procedureItemActionExclude.getExcludeProcedureItemActionIds());
                                }
                            }
                        });
                    }
                }
            }
        }
        if (!CollectionUtils.isEmpty(removeProcedureItemActionIdSet)) {
            for (Integer integer : removeProcedureItemActionIdSet) {
                GsProcedureItemActionGroupDTO gsProcedureItemActionGroupDTO = gsProcedureItemActionGroupDtoListForProcedureItemActionIdMap.get(integer);
                gsProcedureItemActionGroupDTOList.remove(gsProcedureItemActionGroupDTO);
                gsProcedureItemActionGroupDtoListForProcedureItemActionIdMap.remove(integer);
            }
        }
        /*对前端传过来的参数进行过滤,去除不满足手续办理模版的数据进行删除*/
        List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> excludeList = new ArrayList<>();
        for (ResumeProcedureItemSaveQuery.ProcedureItemActionQuery needSaveProcedureItemAction : needSaveProcedureItemActions) {
            Integer procedureItemActionId = needSaveProcedureItemAction.getProcedureItemActionId();
            GsProcedureItemActionGroupDTO gsProcedureItemActionGroupDTO = gsProcedureItemActionGroupDtoListForProcedureItemActionIdMap.get(procedureItemActionId);
            if (Objects.isNull(gsProcedureItemActionGroupDTO)) {
                excludeList.add(needSaveProcedureItemAction);
            } else {
                Boolean grouped = gsProcedureItemActionGroupDTO.getGrouped();
                if (grouped) {
                    List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> procedureItemActions = needSaveProcedureItemAction.getProcedureItemActions();
                    List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> excludeGroupChildList = new ArrayList<>();
                    if (!CollectionUtils.isEmpty(procedureItemActions)) {
                        for (ResumeProcedureItemSaveQuery.ProcedureItemActionQuery procedureItemAction : procedureItemActions) {
                            List<GsProcedureItemActionWithTypeDTO> groupChildList = gsProcedureItemActionGroupDTO.getGroupChildList();
                            if (Objects.isNull(groupChildList)) {
                                excludeGroupChildList.add(procedureItemAction);
                            } else {
                                Set<Integer> groupChildIdSet = groupChildList.stream().map(GsProcedureItemAction::getProcedureItemActionId).collect(Collectors.toSet());
                                if (!groupChildIdSet.contains(procedureItemAction.getProcedureItemActionId())) {
                                    excludeGroupChildList.add(procedureItemAction);
                                }
                            }
                        }
                        procedureItemActions.removeAll(excludeGroupChildList);
                    }
                }
            }
        }
        needSaveProcedureItemActions.removeAll(excludeList);
    }


    private List<ProcedureItemActionWrapper> processGroupActionValue(GsProcedureItemActionGroupDTO
                                                                             gsProcedureItemActionGroupDTO,
                                                                     Map<Integer, List<ProcedureItemActionValueDTO>> procedureItemActionValueDtoListForActionIdMap,
                                                                     List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> procedureItemActionQueries) {
        Boolean groupRequired = gsProcedureItemActionGroupDTO.getRequired();
        Integer groupMaxCount = gsProcedureItemActionGroupDTO.getMaxCount();
        String groupedChName = gsProcedureItemActionGroupDTO.getChName();
        String groupedEnName = gsProcedureItemActionGroupDTO.getEnName();
        if (groupRequired) {
            if (CollectionUtils.isEmpty(procedureItemActionQueries)) {
                String chMsg = StringUtils.isEmpty(groupedChName) ? "请填写必填内容" : groupedChName + "分组为必填项";
                String enMsg = StringUtils.isEmpty(groupedEnName) ? "Please fill in the required content" : groupedEnName + " is required";
                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chMsg, enMsg);
            }
        }
        if (CollectionUtils.isEmpty(procedureItemActionQueries)) {
            return Collections.emptyList();
        }
        if (groupMaxCount != 0 && procedureItemActionQueries.size() > groupMaxCount) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, groupedChName + "分组最多" + groupMaxCount + "份", groupedEnName + " group max count limit " + groupMaxCount);
        }
        List<ProcedureItemActionWrapper> procedureItemActionWrappers = new ArrayList<>();
        List<GsProcedureItemActionWithTypeDTO> groupChildList = gsProcedureItemActionGroupDTO.getGroupChildList();
        for (ResumeProcedureItemSaveQuery.ProcedureItemActionQuery procedureItemActionQuery : procedureItemActionQueries) {
            ProcedureItemActionWrapper procedureItemActionWrapperGroup = new ProcedureItemActionWrapper(gsProcedureItemActionGroupDTO, procedureItemActionQuery.getOrders());
            procedureItemActionWrappers.add(procedureItemActionWrapperGroup);
            List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> procedureItemActions = procedureItemActionQuery.getProcedureItemActions();
            if (!CollectionUtils.isEmpty(procedureItemActions)) {
                List<ProcedureItemActionWrapper> groupChild = new ArrayList<>(procedureItemActionQueries.size());
                for (GsProcedureItemActionWithTypeDTO gsProcedureItemAction : groupChildList) {
                    ProcedureItemActionWrapper procedureItemActionWrapper = processNormalActionValue(gsProcedureItemAction, procedureItemActionValueDtoListForActionIdMap, procedureItemActions);
                    if (!Objects.isNull(procedureItemActionWrapper)) {
                        groupChild.add(procedureItemActionWrapper);
                    }
                }
                procedureItemActionWrapperGroup.setGroupChild(groupChild);
            }
        }
        return procedureItemActionWrappers;
    }

    @SuppressWarnings("all")/*逻辑超80行,无须拆方法*/
    private ProcedureItemActionWrapper processNormalActionValue(GsProcedureItemActionWithTypeDTO
                                                                        gsProcedureItemAction, Map<Integer, List<ProcedureItemActionValueDTO>> procedureItemActionValueDTOListForActionIdMap, List<ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> procedureItemActionQueries) {
        if (Objects.isNull(gsProcedureItemAction)) {
            return null;
        }
        Map<Integer, ResumeProcedureItemSaveQuery.ProcedureItemActionQuery> procedureItemActionQueryListForActionIdMap;
        if (CollectionUtils.isEmpty(procedureItemActionQueries)) {
            procedureItemActionQueryListForActionIdMap = Collections.emptyMap();
        } else {
            procedureItemActionQueryListForActionIdMap = procedureItemActionQueries.stream().collect(Collectors.toMap(ResumeProcedureItemSaveQuery.ProcedureItemActionQuery::getProcedureItemActionId, value -> value));
        }
        Integer procedureItemActionId = gsProcedureItemAction.getProcedureItemActionId();
        Boolean required = gsProcedureItemAction.getRequired();
        Integer maxCount = gsProcedureItemAction.getMaxCount();
        String chName = gsProcedureItemAction.getChName();
        String enName = gsProcedureItemAction.getEnName();
        String actionType = gsProcedureItemAction.getActionType();
        String valueType = gsProcedureItemAction.getValueType();
        String valueTypeCode = gsProcedureItemAction.getValueTypeCode();
        ProcedureItemActionTypeEnum procedureItemActionTypeEnum = ProcedureItemActionTypeEnum.get(actionType);
        if (Objects.isNull(procedureItemActionTypeEnum)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "请联系系统管理员配置行为类型", "Please contact the system administrator to configure the behavior type");
        }
        ProcedureValueTypeEnum procedureValueTypeEnum = ProcedureValueTypeEnum.get(valueType);
        ResumeProcedureItemSaveQuery.ProcedureItemActionQuery procedureItemActionQuery = procedureItemActionQueryListForActionIdMap.get(procedureItemActionId);
        if (Objects.isNull(procedureItemActionQuery)) {
            if (required) {
                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "为必填项", enName + " is required");
            }
        } else {
            Integer orders = procedureItemActionQuery.getOrders();
            List<String> procedureItemActionValues = procedureItemActionQuery.getProcedureItemActionValues();
            if (required && CollectionUtils.isEmpty(procedureItemActionValues)) {
                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "为必填项", enName + " is required");
            }
            List<ProcedureItemActionValueDTO> procedureItemActionValueDTOList = procedureItemActionValueDTOListForActionIdMap.get(procedureItemActionId);
            ProcedureItemActionWrapper procedureItemActionWrapper = new ProcedureItemActionWrapper(gsProcedureItemAction, orders);
            List<ProcedureItemActionValueWrapper> procedureItemActionValueWrappers = new ArrayList<>();
            procedureItemActionWrapper.setProcedureItemActionValueWrappers(procedureItemActionValueWrappers);
            if (!CollectionUtils.isEmpty(procedureItemActionValues)) {
                switch (procedureItemActionTypeEnum) {
                    case DATE:
                    case DATE_TIME:
                    case INTEGER_INPUT:
                    case NUMBER_INPUT:
                    case TEXT_INPUT:
                    case TEXT_INPUT_TEXTAREA:
                        if (procedureItemActionValues.size() > 1) {
                            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "只允许填写一份", enName + " only one copy is allowed");
                        }
                        procedureItemActionValueWrappers.add(new ProcedureItemActionValueWrapper.Builder(procedureItemActionId, actionType)
                                .value(procedureItemActionValues.get(0)).build());
                        break;
                    case FILE_UPLOAD:
                        if (maxCount != 0 && procedureItemActionValues.size() > maxCount) {
                            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + ":最多可上传" + maxCount + "个文件", enName + ":Up to " + maxCount + " files max can be uploaded");
                        }
                        for (String procedureItemActionValue : procedureItemActionValues) {
                            boolean isLegal = FileSuffixUtil.fileUrlContainSuffix(procedureItemActionValue, FileTypeConstants.DOC,
                                    FileTypeConstants.DOCX,
                                    FileTypeConstants.JPEG,
                                    FileTypeConstants.JPG,
                                    FileTypeConstants.PDF,
                                    FileTypeConstants.PNG,
                                    FileTypeConstants.XLS,
                                    FileTypeConstants.XLSX);
                            if (!isLegal) {
                                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "不支持的文件类型", enName + " unsupported file type");
                            }
                            procedureItemActionValueWrappers.add(new ProcedureItemActionValueWrapper.Builder(procedureItemActionId, actionType)
                                    .value(procedureItemActionValue).build());
                        }
                        break;
                    case VALUE_RADIO:
                        if (procedureItemActionValues.size() > 1) {
                            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "只允许选择一项", enName + " is only one option is allowed");
                        }
                        String s = procedureItemActionValues.get(0);
                        if (!procedureValueTypeEnum.isNone()) {
                            if (NumberUtils.isParsable(s)) {
                                boolean hit = false;
                                if (procedureValueTypeEnum.isValues()) {
                                    for (ProcedureItemActionValueDTO procedureItemActionValueDTO : procedureItemActionValueDTOList) {
                                        Integer id = NumberUtils.toInt(s);
                                        if (procedureItemActionValueDTO.getProcedureItemActionValueId().equals(id)) {
                                            procedureItemActionValueWrappers.add(new ProcedureItemActionValueWrapper.Builder(procedureItemActionId, actionType)
                                                    .id(id)
                                                    .chName(procedureItemActionValueDTO.getChName())
                                                    .enName(procedureItemActionValueDTO.getEnName())
                                                    .build());
                                            hit = true;
                                        }
                                    }
                                }
                                if (procedureValueTypeEnum.isSysDict()) {
                                    if (NumberUtils.isParsable(valueTypeCode)) {
                                        List<GsSysDictVo> gsSysDictVos = gsSysDictMapper.selectByCodeType(null, NumberUtils.toInt(valueTypeCode));
                                        List<ProcedureItemActionValueDTO> procedureItemActionValueDTOListForSysDict = ResumeProcedureCommonUtil.sysDict2ProcedureItemActionValueDTO(procedureItemActionId, gsSysDictVos);
                                        for (ProcedureItemActionValueDTO procedureItemActionValueDTO : procedureItemActionValueDTOListForSysDict) {
                                            Integer id = NumberUtils.toInt(s);
                                            if (procedureItemActionValueDTO.getProcedureItemActionValueId().equals(id)) {
                                                procedureItemActionValueWrappers.add(new ProcedureItemActionValueWrapper.Builder(procedureItemActionId, actionType)
                                                        .id(id)
                                                        .chName(procedureItemActionValueDTO.getChName())
                                                        .enName(procedureItemActionValueDTO.getEnName())
                                                        .build());
                                                hit = true;
                                            }
                                        }
                                    }
                                }
                                if (!hit && required) {
                                    throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "为必填项", enName + " is required");
                                }
                            } else {
                                if (required) {
                                    throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "选项值不合法", enName + " option value is invalid");
                                }
                            }
                        }
                        break;
                    case VALUE_CHECK:
                        List<Integer> checkValueIds = procedureItemActionValues.stream().filter(NumberUtils::isCreatable).map(NumberUtils::toInt).collect(Collectors.toList());
                        if (CollectionUtils.isEmpty(checkValueIds)) {
                            if (required) {
                                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "为必填项", enName + " is required");
                            }
                        } else {
                            boolean hit = false;
                            if (!procedureValueTypeEnum.isNone()) {
                                if (procedureValueTypeEnum.isValues()) {
                                    for (ProcedureItemActionValueDTO procedureItemActionValueDTO : procedureItemActionValueDTOList) {
                                        if (checkValueIds.contains(procedureItemActionValueDTO.getProcedureItemActionValueId())) {
                                            procedureItemActionValueWrappers.add(new ProcedureItemActionValueWrapper.Builder(procedureItemActionId, actionType)
                                                    .id(procedureItemActionValueDTO.getProcedureItemActionValueId())
                                                    .chName(procedureItemActionValueDTO.getChName())
                                                    .enName(procedureItemActionValueDTO.getEnName())
                                                    .build());
                                            hit = true;
                                        }
                                    }
                                }
                                if (procedureValueTypeEnum.isSysDict()) {
                                    if (NumberUtils.isParsable(valueTypeCode)) {
                                        List<GsSysDictVo> gsSysDictVos = gsSysDictMapper.selectByCodeType(null, NumberUtils.toInt(valueTypeCode));
                                        List<ProcedureItemActionValueDTO> procedureItemActionValueDTOListForSysDict = ResumeProcedureCommonUtil.sysDict2ProcedureItemActionValueDTO(procedureItemActionId, gsSysDictVos);
                                        for (ProcedureItemActionValueDTO procedureItemActionValueDTO : procedureItemActionValueDTOListForSysDict) {
                                            if (checkValueIds.contains(procedureItemActionValueDTO.getProcedureItemActionValueId())) {
                                                procedureItemActionValueWrappers.add(new ProcedureItemActionValueWrapper.Builder(procedureItemActionId, actionType)
                                                        .id(procedureItemActionValueDTO.getProcedureItemActionValueId())
                                                        .chName(procedureItemActionValueDTO.getChName())
                                                        .enName(procedureItemActionValueDTO.getEnName())
                                                        .build());
                                                hit = true;
                                            }
                                        }
                                    }
                                }
                            }
                            if (!hit && required) {
                                throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, chName + "为必填项", enName + " is required");
                            }
                        }
                        break;
                    default:
                }
            }
            return procedureItemActionWrapper;
        }
        return null;
    }

    /**
     * 将模版结构处理
     *
     * @param gsProcedureItemActionList 模版数据
     * @return 处理后的
     */
    private List<GsProcedureItemActionGroupDTO> procedureItemActionToGsProcedureItemActionGroupDTO
    (List<GsProcedureItemActionWithTypeDTO> gsProcedureItemActionList) {
        /*源数据转成行为id为key的map*/
        Map<Integer, GsProcedureItemActionWithTypeDTO> procedureItemActionForActionIdMap = gsProcedureItemActionList.stream().filter(StreamUtil.distinctByKey((Function<GsProcedureItemActionWithTypeDTO, Integer>) GsProcedureItemAction::getProcedureItemActionId)).collect(Collectors.toMap(GsProcedureItemAction::getProcedureItemActionId, value -> value));
        /*分组的*/
        List<GsProcedureItemAction> gsProcedureItemActionGroupedList = gsProcedureItemActionList.stream().filter(GsProcedureItemActionWithTypeDTO::getGrouped).collect(Collectors.toList());
        /*分组的行为id*/
        List<Integer> gsProcedureItemActionGroupedIdList = gsProcedureItemActionGroupedList.stream().map(GsProcedureItemAction::getProcedureItemActionId).collect(Collectors.toList());

        List<GsProcedureItemActionGroupDTO> gsProcedureItemActionGroupDTOList = new ArrayList<>();
        Set<Integer> procedureItemActionIds = new HashSet<>();
        if (!CollectionUtils.isEmpty(gsProcedureItemActionGroupedIdList)) {
            List<GsProcedureItemActionGroupMap> gsProcedureItemActionGroupMaps = gsProcedureItemActionGroupMapMapper.selectByProcedureItemActionGroupedIds(gsProcedureItemActionGroupedIdList);
            /*分组关系分成组*/
            Map<Integer, List<GsProcedureItemActionGroupMap>> gsProcedureItemActionGroupMapsForActionIdMap = gsProcedureItemActionGroupMaps.stream().collect(Collectors.groupingBy(GsProcedureItemActionGroupMap::getProcedureItemActionGroupId));
            /*遍历分组的映射关系*/
            gsProcedureItemActionGroupMapsForActionIdMap.forEach((procedureItemActionId, gsProcedureItemActionGroupMaps1) -> {
                GsProcedureItemActionWithTypeDTO gsProcedureItemActionGroup = procedureItemActionForActionIdMap.get(procedureItemActionId);
                procedureItemActionIds.add(procedureItemActionId);
                GsProcedureItemActionGroupDTO gsProcedureItemActionGroupDTO = new GsProcedureItemActionGroupDTO(gsProcedureItemActionGroup);
                Boolean required = gsProcedureItemActionGroupDTO.getRequired();
                List<GsProcedureItemActionWithTypeDTO> gsProcedureItemActionChildList = new ArrayList<>(gsProcedureItemActionGroupMaps1.size());
                for (GsProcedureItemActionGroupMap gsProcedureItemActionGroupMap : gsProcedureItemActionGroupMaps1) {
                    GsProcedureItemActionWithTypeDTO gsProcedureItemAction = procedureItemActionForActionIdMap.get(gsProcedureItemActionGroupMap.getProcedureItemActionId());
                    if (!Objects.isNull(gsProcedureItemAction)) {
                        gsProcedureItemAction.setRequired(required);
                        gsProcedureItemActionChildList.add(gsProcedureItemAction);
                        procedureItemActionIds.add(gsProcedureItemAction.getProcedureItemActionId());
                    }
                }
                gsProcedureItemActionGroupDTO.setGroupChildList(gsProcedureItemActionChildList);
                gsProcedureItemActionGroupDTOList.add(gsProcedureItemActionGroupDTO);
            });
        }
        List<GsProcedureItemActionWithTypeDTO> gsProcedureItemActions = new ArrayList<>();
        if (CollectionUtils.isEmpty(procedureItemActionIds)) {
            gsProcedureItemActions = gsProcedureItemActionList;
        } else {
            for (GsProcedureItemActionWithTypeDTO gsProcedureItemAction : gsProcedureItemActionList) {
                if (!procedureItemActionIds.contains(gsProcedureItemAction.getProcedureItemActionId())) {
                    gsProcedureItemActions.add(gsProcedureItemAction);
                }
            }
        }
        for (GsProcedureItemActionWithTypeDTO gsProcedureItemAction : gsProcedureItemActions) {
            gsProcedureItemActionGroupDTOList.add(new GsProcedureItemActionGroupDTO(gsProcedureItemAction));
        }
        return gsProcedureItemActionGroupDTOList.stream().filter(StreamUtil.distinctByKey((Function<GsProcedureItemAction, Integer>) GsProcedureItemAction::getProcedureItemActionId)).collect(Collectors.toList());
    }

    /**
     * 简历的手续办理项忽略处理(不需要上传功能)
     *
     * @param resumeId              简历id
     * @param resumeProcedureItemId 简历的手续办理项id
     */
    public void resumeProcedureItemProcessIgnore(Integer resumeId, Integer resumeProcedureItemId) {
        GsResumeProcedure gsResumeProcedure = gsResumeProcedureMapper.selectByResumeId(resumeId);
        if (Objects.isNull(gsResumeProcedure)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "未到手续办理流程", "The procedure hasn't arrived yet");
        }
        Integer resumeProcedureId = gsResumeProcedure.getResumeProcedureId();
        List<Integer> procedureTypes = gsResumeProcedureTypeMapper.selectProcedureTypes(resumeProcedureId);
        GsResumeProcedureItem gsResumeProcedureItem = gsResumeProcedureItemMapper.selectByResumeProcedureIdAndId(resumeProcedureId, resumeProcedureItemId);
        if (Objects.isNull(gsResumeProcedureItem)) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "简历的手续办理并无此项", "There is no such item in the procedure of resume");
        }
        Integer processingStatus = gsResumeProcedureItem.getProcessingStatus();
        ResumeProcedureItemProcessingStatusEnum resumeProcedureItemProcessingStatusEnum = ResumeProcedureItemProcessingStatusEnum.get(processingStatus);
        if (resumeProcedureItemProcessingStatusEnum.isProcessed()) {
            throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW, "简历的手续办理已完成,如需修改请联系您的负责人", "Resume process has been completed, if you need to modify, please contact your person in charge");
        }
        gsResumeProcedureItem.setPartyId(Objects.requireNonNull(UserUtil.getParty()).getCode());
        gsResumeProcedureItem.setOperateUserId(UserUtil.getUserId());
        gsResumeProcedureItem.setProcessingStatus(ResumeProcedureItemProcessingStatusEnum.PROCESSED_IGNORE.getValue());
        gsResumeProcedureItemMapper.updateById(gsResumeProcedureItem);
        procedureContentFlagUtil.procedureItemProcessed(gsResumeProcedureItem);
        procedureMessageUtil.pushItemNodeMessage(resumeId, procedureTypes, gsResumeProcedureItem);
        Integer procedureUserRole = procedureRoleHandler.getCurrentUserProcedureUserRole();
        processAutoRevealApp(resumeId, procedureUserRole, procedureTypes, gsResumeProcedureItem);
    }
}
