package com.gosingapore.common.util.redis;

import com.cloud.gs.hiring.base.util.ResponseCode;
import com.gosingapore.common.exception.CustomizeException;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

/**
 * @author huangchengqian
 * @date 2020-10-17 10:48
 **/
@Component
public class RedisLockComponent {

    @Resource
    private RedisTemplate<String, Object> redisTemplate;

    private static final long DEFAULT_LOCK_TIME = 5;

    private static final String DEFAULT_LOCK_VALUE = "lock";

    public <T> T tryLock(String key, Callback<T> callback) {
        return tryLock(key, DEFAULT_LOCK_TIME, callback);
    }

    public <T> T tryLock(String key, long timeout, Callback<T> callback) {
        return tryLock(key, DEFAULT_LOCK_VALUE, timeout, TimeUnit.SECONDS, callback);
    }

    public <T> T tryLock(String key, Object value, long timeout, TimeUnit unit, Callback<T> callback) {
        return tryLock(key, value, timeout, unit, callback, null);
    }

    public <T> T tryLock(String key, Object value, long timeout, TimeUnit unit, Callback<T> callback, CustomizeExceptionFunction customizeExceptionFunction) {
        Boolean lock = null;
        try {
            lock = redisTemplate.opsForValue().setIfAbsent(key, value, timeout, unit);
            if (Objects.isNull(lock)) {
                throw new CustomizeException(ResponseCode.SYS_INTERNAL_SERVER_ERROR, "redis锁服务失效", "Redis lock service fails");
            }
            if (lock) {
                return callback.callback();
            } else {
                if (Objects.isNull(customizeExceptionFunction)) {
                    throw new CustomizeException(ResponseCode.COMMON_NOT_ALLOW_REPEAT, "请不要重复操作", "Please do not repeat the operation!");
                } else {
                    throw customizeExceptionFunction.createCustomizeException();
                }
            }
        } finally {
            if (Objects.nonNull(lock) && lock) {
                this.redisTemplate.delete(key);
            }
        }
    }

}
